package org.vcs.bazaar.eclipse.core.commands;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.vcs.bazaar.client.testUtils.FileUtils.addContentToFile;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.core.runtime.Path;
import org.junit.Test;
import org.vcs.bazaar.client.BazaarStatusKind;
import org.vcs.bazaar.client.BazaarTreeStatus;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.TestCaseWithProject;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;

/**
 * 
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 *
 */
public class CommitCommandTest extends TestCaseWithProject {

	@Test
	public final void testExecute() throws Exception {
		final List<IBzrLocalResource> resources = new ArrayList<IBzrLocalResource>();
		final IFile res = getProject().getFile(new Path("file_in_root.txt"));
		assertNotNull(res);
		IBzrLocalResource bzrRes = BzrWorkspaceRoot.getBzrFileFor(res);
		assertNotNull(bzrRes);
		resources.add(bzrRes);
		// modify a existing file
		final File aFile = res.getLocation().toFile();
		final String textToAdd = "this is text added to " + aFile.getName();
		addContentToFile(aFile, textToAdd);

		// change the expectedWorkingTree to the expected status
		getWt().setItemStatus(aFile.getName(), BazaarStatusKind.MODIFIED);
		String currentContent = getWt().getItemContent(aFile.getName());
		getWt().setItemContent(aFile.getName(), currentContent + textToAdd);

		// Check if status is ok
		getClient().setWorkDir(getProject().getLocation().toFile());
		BazaarTreeStatus treeStatus = getClient().status(new File[] { getProject().getLocation().toFile() });
		getWt().check(treeStatus.getStatusAsArray(), getProject().getLocation().toFile().getCanonicalPath());
		
		CommitCommand cmd = new CommitCommand(resources, "test commit", new ArrayList<Option>(0));
		IResource[] commitedResources = cmd.execute(new NullProgressMonitor());
		assertNotNull(commitedResources);
		assertEquals(1, commitedResources.length);
		assertEquals(res, commitedResources[0]);
	}
	
	@Test
	public void testExecuteEncoding() throws Exception {
		final List<IBzrLocalResource> resources = new ArrayList<IBzrLocalResource>();
		final IFile res = getProject().getFile(new Path("file_in_root.txt"));
		assertNotNull(res);
		IBzrLocalResource bzrRes = BzrWorkspaceRoot.getBzrFileFor(res);
		assertNotNull(bzrRes);
		resources.add(bzrRes);
		// modify a existing file
		final File aFile = res.getLocation().toFile();
		final String textToAdd = "this is text added to " + aFile.getName();
		addContentToFile(aFile, textToAdd);
		
		CommitCommand cmd = new CommitCommand(resources, "Příšrně žlutý kůň úpěl ďábelské ódy (czech language)", new ArrayList<Option>(0));
		IResource[] commitedResources = cmd.execute(new NullProgressMonitor());
		assertNotNull(commitedResources);
		assertEquals(1, commitedResources.length);
		assertEquals(res, commitedResources[0]);
	}
}
