package org.vcs.bazaar.eclipse.core.commands;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.util.Map;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.junit.Test;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.TestCaseWithProject;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 *
 */
public class IgnoredCommandTest extends TestCaseWithProject {

	@Test
	public final void testSingleFile() throws Exception {
		IFile ignoredfile = getProject().getFile("ignored_file");
		InputStream is = new ByteArrayInputStream("foobar".getBytes());
		ignoredfile.create(is, true, new NullProgressMonitor());
		getProject().refreshLocal(IResource.DEPTH_INFINITE, new NullProgressMonitor());
		IBzrLocalResource bzrRes = BzrWorkspaceRoot.getBzrFileFor(ignoredfile);
		
		getClient().setWorkDir(getProject().getLocation().toFile());
		getClient().ignore(getProject().getLocation().toFile(), bzrRes.getName());
		IgnoredCommand cmd = new IgnoredCommand(getProject());
		cmd.run(new NullProgressMonitor());
		Map<IResource, String> ignored = cmd.getIgnored();
		assertNotNull(ignored);
		assertEquals(1, ignored.size());
		assertNotNull(ignored.get(ignoredfile));
		assertEquals(ignoredfile, ignored.keySet().iterator().next());
	}
}
