/**
 * 
 */
package org.vcs.bazaar.eclipse.core.repository;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.io.File;
import java.net.URISyntaxException;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 *
 */
public class BranchFactoryTest {

	private File tempDir;
	private String branchDir;
	private File theFile;

	@Before
	public void setUp() {
		tempDir = new File(System.getProperty("java.io.tmpdir"));
		branchDir = "C:/Documents and Settings/dangoore/My Documents/EclipseBZRWorkspace/MyProject";
		theFile = new File(tempDir, branchDir);
		theFile.mkdirs();
	}
	
	@After
	public void tearDown() {
		theFile.delete();
	}
	
	/**
	 * Test method for {@link org.vcs.bazaar.eclipse.core.repository.BranchFactory#findOrCreateFor(java.net.URI)}.
	 */
	@Test
	public void testFindOrCreateForURI() {
		IBzrBranch branch = BranchFactory.getInstance().findOrCreateFor(theFile.toURI());
		assertNotNull(branch);
		assertEquals(theFile.toURI(), branch.getLocation());
	}

	/**
	 * Test method for {@link org.vcs.bazaar.eclipse.core.repository.BranchFactory#findOrCreateFor(java.lang.String)}.
	 * @throws URISyntaxException 
	 */
	@Test
	public void testFindOrCreateForString() throws URISyntaxException {
		IBzrBranch branch = BranchFactory.getInstance().findOrCreateFor(theFile.getAbsolutePath());
		assertNotNull(branch);
		assertEquals(theFile.getAbsolutePath().replace(" ", "%20"), branch.getBranchLocation().toString());
	}

	/**
	 * Test method for {@link org.vcs.bazaar.eclipse.core.repository.BranchFactory#validateBranch(java.lang.String)}.
	 */
	@Test
	public void testValidateBranch() {
		assertTrue(BranchFactory.validateBranch(theFile.getAbsolutePath()));
	}

}
