package org.vcs.bazaar.eclipse.core;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResourceChangeListener;
import org.eclipse.core.runtime.jobs.ILock;
import org.eclipse.core.runtime.jobs.Job;
import org.vcs.bazaar.eclipse.core.listeners.IResourceStateListener;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.IBzrResource;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.core.model.remote.IBzrRemoteResource;

public abstract class AbstractCacheManager implements IResourceChangeListener, IResourceStateListener {

	protected final static ILock NULL_LOCK = new NullLock();
	
	private Map<Object, ILock> lockMap = new HashMap<Object, ILock>();


	/** 
	 * This is a helper method, to get a ILock from the jobManager.
	 * 
	 * @param project
	 * @return a ILock for the specified IProject
	 */
	protected ILock getLock(IProject project) {
		return getOrCreateLock(project);
	}
	
	protected ILock getLock(IBzrResource bzrResource) {
		if(bzrResource instanceof IBzrBranch || bzrResource instanceof IBzrRemoteResource) {
			return NULL_LOCK;
		} else {
			final IBzrLocalResource locRes = (IBzrLocalResource)bzrResource;
			return getLock(locRes.getIResource().getProject());
		}
	}
	
	private ILock getOrCreateLock(Object obj) {
		ILock lock = lockMap.get(obj);
		if(lock == null) {
			lock = Job.getJobManager().newLock();
			lockMap.put(obj, lock);
		}
		return lock;
	}
	
	protected static class NullLock implements ILock {
		public void acquire() {}
		public boolean acquire(long delay) throws InterruptedException {return true; }
		public void release() {}
		public int getDepth() {return 0;}
	}

}