/*******************************************************************************
 * Copyright (c) 2003, 2006 Subclipse project and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Subclipse project committers - initial API and implementation
 ******************************************************************************/
package org.vcs.bazaar.eclipse.core.client;

import java.io.File;

import org.vcs.bazaar.client.IBazaarNotifyListener;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;

/**
 * a redirect to the console
 */
public class NotificationListener implements IBazaarNotifyListener {

	private static final NotificationListener instance = new NotificationListener();

	/*
	 * private constructor
	 */
	private NotificationListener() {

	}

	private IBazaarNotifyListener getConsoleListener() {
		return EclipseBazaarCore.getDefault().getConsoleListener();
	}

	/**
	 * Returns the singleton instance
	 */
	public static NotificationListener getInstance() {
		return instance;
	}

	public void logCommandLine(String commandLine) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.logCommandLine(commandLine);
		}
	}

	public void logRevision(long revision, String path) {
	}

	public void logCompleted(String message) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.logCompleted(message);
		}
	}

	public void logError(String message) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.logError(message);
		}
	}

	public void logMessage(String message) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.logMessage(message);
		}
	}

	public void onNotify(File path) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.onNotify(path);
		}
	}

	public void setCommand(int command) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.setCommand(command);
		}
	}

	public void logCommandOutput(String message) {
		IBazaarNotifyListener consoleListener = getConsoleListener();
		if (consoleListener != null) {
			consoleListener.logCommandOutput(message);
		}
	}

}
