/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import java.io.File;
import java.util.List;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 * 
 */
public class AddCommand extends ResourceChangeCommand {

	private final List<? extends IResource> resources;
	private final BzrWorkspaceRoot root;

	public AddCommand(BzrWorkspaceRoot bzrWorkspaceRoot, List<? extends IResource> resources) {
		this.root = bzrWorkspaceRoot;
		this.resources = resources;
	}

	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		try {
			root.getClient().add(getFiles(resources));
			return resources.toArray(new IResource[0]);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, root.getBranch().getProject());
		}
	}

	private static File[] getFiles(List<? extends IResource> resources) {
		File[] files = new File[resources.size()];
		for (int i = 0; i < resources.size(); i++) {
			files[i] = resources.get(i).getLocation().toFile();
		}
		return files;
	}

}
