/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarAnnotation;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class AnnotateCommand extends BazaarCommand {

	private final IBzrLocalResource resource;
	private IBazaarAnnotation annotation;

	public AnnotateCommand(IBzrLocalResource bzrResource) {
		this.resource = bzrResource;
	}

	/**
	 * when this finish you must call {@link #getAnnotation()}
	 * 
	 * @see org.vcs.bazaar.eclipse.core.commands.IBazaarCommand#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.AnnotateCommand_annotate, 1000);
			IBazaarClient client = getClient(resource.getIResource().getProject());
			annotation = client.annotate(resource.getIResource().getLocation().toFile());
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, resource.getIResource());
		} finally {
			monitor.done();
		}
	}

	public IBazaarAnnotation getAnnotation() {
		return annotation;
	}

}
