/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import java.io.File;
import java.net.URI;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BazaarClientException.BazaarUncheckedException;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez TODO: add revision support and write a testcase
 */
public class BranchCommand implements IBazaarCommand {

	private final IBzrBranch remoteLocation;
	private BazaarRevision revision;
	private final URI toLocation;

	public BranchCommand(final IBzrBranch sourceLocation, final IProject project, String revision) {
		this(sourceLocation, project.getLocationURI(), revision);
	}
	
	public BranchCommand(final IBzrBranch sourceLocation, final URI toLocation, String revision) {
		this.remoteLocation = sourceLocation;
		this.toLocation = toLocation;
		if (revision != null && revision.trim().length() != 0) {
			try {
				this.setRevision(BazaarRevision.getRevision(BazaarRevision.Prefix.REVNO, revision));
			} catch (BazaarUncheckedException e) {
				// TODO Handle bad revision
				EclipseBazaarCore.log(e.getMessage(), e);
				this.setRevision(null);
			}
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.vcs.bazaar.eclipse.core.operations.IBazaarOperation#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			final IBazaarClient client = EclipseBazaarCore.getDefault().createClient();
			
			File toLocationFolder = new File(getToLocation());			
			client.setWorkDir(toLocationFolder);
			// to get the location of a nonexistent project:
			client.branch(getRemoteLocation().getBranchLocation(), toLocationFolder, getRevision());
		} catch (BazaarClientException e) {
			EclipseBazaarCore.log(e.getMessage(), e);
			throw BazaarException.wrapException(e);
		}
	}

	/**
	 * @return the toLocation
	 */
	protected URI getToLocation() {
		return toLocation;
	}

	/**
	 * @param revision the revision to set
	 */
	protected void setRevision(BazaarRevision revision) {
		this.revision = revision;
	}

	/**
	 * @return the revision
	 */
	protected BazaarRevision getRevision() {
		return revision;
	}

	/**
	 * @return the remoteLocation
	 */
	protected IBzrBranch getRemoteLocation() {
		return remoteLocation;
	}

}
