/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import java.io.InputStream;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalFile;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class CatCommand extends BazaarCommand {

	private IBzrLocalFile resource;
	private BazaarRevision revision;
	private InputStream content;

	public CatCommand(IBzrLocalFile resource, BazaarRevision revision) {
		this.resource = resource;
		this.revision = revision;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.vcs.bazaar.eclipse.core.commands.IBazaarCommand#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.CatCommand_taskName, 1000);
			IBazaarClient client = getClient(resource.getBranch());
			String charsetName;
			try {
				charsetName = resource.getIFile().getCharset();
			} catch (CoreException e) {
				charsetName = null;
			}
			content = client.cat(resource.getIResource().getLocation().toFile(), revision, charsetName);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, ((IBzrLocalResource)resource).getIResource());
		} finally {
			monitor.done();
		}
	}

	public InputStream getContent() {
		return content;
	}

}
