/**
 * 
 */
package org.vcs.bazaar.eclipse.core.commands;

import java.io.File;
import java.net.URI;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 *
 */
public class CheckoutCommand extends BranchCommand {

	private final Option[] options;

	public CheckoutCommand(final IBzrBranch sourceLocation, final IProject project, Option...options) {
		this(sourceLocation, project.getLocationURI(), options);
	}
	
	public CheckoutCommand(final IBzrBranch sourceLocation, final URI toLocation, Option...options) {
		super(sourceLocation, toLocation, null);
		this.options = options;
	}
	
	public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			final IBazaarClient client = EclipseBazaarCore.getDefault().createClient();
			
			File toLocationFolder = new File(getToLocation());
			client.setWorkDir(toLocationFolder);
			// to get the location of a nonexistent project:
			client.checkout(getRemoteLocation().getBranchLocation(), toLocationFolder, options);
		} catch (BazaarClientException e) {
			EclipseBazaarCore.log(e.getMessage(), e);
			throw BazaarException.wrapException(e);
		}
	}
	
	
}
