/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import java.io.File;
import java.util.List;
import java.util.Map;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class CommitCommand extends StateChangeCommand {

	private String commitMessage;
	private List<IBzrLocalResource> resources;
	final private List<Option> options;
	private boolean fullCommit;
	
	/**
	 * 
	 * @param filesToCommit 
	 * 					a list of IBzrResource that can belongs to different branches
	 * @param commitMessage
	 * @param localCommit
	 */
    public CommitCommand(List<IBzrLocalResource> filesToCommit, String commitMessage, List<Option> options) {
		this.resources = filesToCommit;
		this.commitMessage = commitMessage;
		this.options = options;
	}
    
    /**
     * 
     * @param filesToCommit
     * @param commitMessage
     * @param options
     * @param fullCommit if tru, the filesToCommit 'll be ignored and a full commit 'll be executed (commit with 0 arguments)
     */
    public CommitCommand(List<IBzrLocalResource> filesToCommit, String commitMessage, List<Option> options, boolean fullCommit) {
		this(filesToCommit, commitMessage, options);
		this.fullCommit = fullCommit;
	}

	/**
	 * execute the commit. 
	 * Actually this method call client.commit(..) for each group of IBzrResource that belong 
	 * to the same branch 
	 *  
	 */
	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		Map<IBzrBranch, List<File>> map = getFilesByBranchMap(resources);
		try {
			monitor.beginTask(CoreTexts.CommitCommand_commit, resources.size());
			for (IBzrBranch branch : map.keySet()) {
				BazaarTeamProvider provider = BzrWorkspaceRoot.getProviderFor(branch.getProject());
				IBazaarClient client = provider.getBzrWorkspaceRoot().getClient();
                if(fullCommit) {
                	client.commit(new File[]{branch.getFile()}, commitMessage, options.toArray(new Option[options.size()]));
                } else {
                	client.commit(map.get(branch).toArray(new File[0]), commitMessage, options.toArray(new Option[options.size()]));	
                }
			}
			return getIResources(resources);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

}
