/**
* Copyright (C) 2009 Canonical Ltd
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
package org.vcs.bazaar.eclipse.core.commands;

import java.io.File;
import java.util.List;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @authors Javier Der Derian<br>
 *  	    Guillermo Gonzalez <guillo.gonzo@gmail.com>
 * @BasedOn AddCommand from BzrEclipse
 */
public class IgnoreCommand extends ResourceChangeCommand {

	private final List<? extends IResource> resources;
	private final BzrWorkspaceRoot root;

	public IgnoreCommand(BzrWorkspaceRoot bzrWorkspaceRoot, List<? extends IResource> resources) {
		this.root = bzrWorkspaceRoot;
		this.resources = resources;
	}

	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		try {
			final File rootfile = this.root.getBranch().getFile();
			for (IResource resource : resources) {
				IBzrLocalResource bzrResource = BzrWorkspaceRoot.getBzrResourceFor(resource);
				root.getClient().ignore(rootfile, bzrResource.getBranchRelativePath().toString());
			}
			return resources.toArray(new IResource[0]);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, root.getBranch().getProject());
		}
	}
}
