/**
* Copyright (C) 2009 Canonical Ltd
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
package org.vcs.bazaar.eclipse.core.commands;

import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.Path;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class IgnoredCommand extends BazaarCommand {

	private final IResource resource;
	private final Map<IResource, String> ignored = new HashMap<IResource, String>();

	public IgnoredCommand(IResource resource) {
		this.resource = resource;
	}

	public void run(IProgressMonitor monitor) throws BazaarException {
		IProgressMonitor subMonitor = EclipseBazaarCore.subProgressMonitorFor(monitor);
		try {
			monitor.beginTask("executing ignored", 10);
			final IBazaarClient client = getClient(resource.getProject());
			final Map<String, String> ignored = client.ignored(resource.getLocation().toFile());
			for (Entry<String, String> entry : ignored.entrySet()) {
				IProject project = resource.getProject();
				IPath fullIgnoredPath = new Path(entry.getKey());
				IPath ignoredPath = fullIgnoredPath.removeFirstSegments(fullIgnoredPath.matchingFirstSegments(project.getLocation()));
				IResource resource = project.findMember(ignoredPath);
				this.ignored.put(resource, entry.getValue());
			}
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, resource);
		} finally {
			subMonitor.done();
		}
	}

	public Map<IResource, String> getIgnored() {
		return this.ignored;
	}
}
