/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.IBazaarInfo;
import org.vcs.bazaar.client.commandline.syntax.IInfoOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class InfoCommand extends BazaarCommand {

	private IProject project;
	private IBazaarInfo info;
	private boolean verbose;

	public InfoCommand(IProject project) {
		this.project = project;
		this.verbose = true;
	}
	
	public InfoCommand(IProject project, boolean verbose) {
		this.project = project;
		this.verbose = verbose;
	}

	public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask("Info command", 10000);
			IBazaarClient client = getClient(project);
			client.getNotificationHandler().disableLog();
			// to improve performance when only the default info is required
			if(verbose)
				info = client.info(project.getLocation().toFile(), IInfoOptions.VERBOSE);
			else
				info = client.info(project.getLocation().toFile());
			client.getNotificationHandler().enableLog();
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, project);
		} finally {
			monitor.done();
		}
	}

	public IBazaarInfo getInfo() {
		return info;
	}

}
