/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import java.io.File;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class InitCommand implements IBazaarCommand {

	private final IProject project;
	private final IPath branchPath;

	public InitCommand(final IPath bzrPath, final IProject project) {
		this.project = project;
		this.branchPath = bzrPath;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.vcs.bazaar.eclipse.core.commands.IBazaarCommand#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			IBazaarClient client = EclipseBazaarCore.getDefault().createClient();
			client.setWorkDir(branchPath.toFile().getParentFile());
			if (project != null && !new File(branchPath.toFile(), IBzrBranch.DIR_META_FOLDER).exists())
				client.init(branchPath.toFile());
		} catch (BazaarClientException e) {
			EclipseBazaarCore.log(e.getMessage(), IStatus.ERROR);
			throw BazaarException.wrapException(e, project);
		}
	}

}
