/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.Path;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.IBazaarItemInfo;
import org.vcs.bazaar.client.commandline.syntax.ILsOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class LsCommand extends BazaarCommand {

	private IResource resource;
	private IBazaarItemInfo[] paths;
	private boolean ignored;

	public LsCommand(IResource resource, boolean ignored) {
		this.resource = resource;
		this.ignored = ignored;
	}

	public void run(IProgressMonitor monitor) throws BazaarException {
		IProgressMonitor subMonitor = EclipseBazaarCore.subProgressMonitorFor(monitor);
		try {
			monitor.beginTask("executing ls", 1000);
			IBazaarClient client = getClient(resource.getProject());
			client.getNotificationHandler().disableLog();
			if(ignored)
				paths = client.ls(resource.getProject().getLocation().toFile(), null, ILsOptions.IGNORED, ILsOptions.VERSIONED);
			else 
				paths = client.ls(resource.getProject().getLocation().toFile(), null, ILsOptions.VERSIONED);
			client.getNotificationHandler().enableLog();
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, resource);
		} finally {
			subMonitor.done();
		}
	}

	public List<IBzrLocalResource> getResources() {
		if (paths == null)
			return null;
		List<IBzrLocalResource> resources = new ArrayList<IBzrLocalResource>(paths.length);
		for (IBazaarItemInfo itemInfo : paths) {
			Path path = new Path(itemInfo.getPath());
			int matchingSegments = this.resource.getProject().getLocation().matchingFirstSegments(path);
			IResource resource = this.resource.getProject().findMember(path.removeFirstSegments(matchingSegments));			
			if (resource != null)
				resources.add(BzrWorkspaceRoot.getBzrResourceFor(resource));
		}
		if(resource.getType() == IResource.PROJECT && !resources.contains(BzrWorkspaceRoot.getBzrResourceFor(resource))) {
			resources.add(BzrWorkspaceRoot.getBzrResourceFor(resource));
		}
		return resources;
	}
}
