/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import java.util.List;
import java.util.Map;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.commandline.syntax.IMergeOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.listeners.BzrChangeStateEvent;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 * 
 */
public class MergeCommand extends MetaModifyCommand {

	private final IProject[] projects;
	private final BranchLocation location;
	private Option[] options;

	public MergeCommand(IProject[] projects, BranchLocation location, Option...options) {
		super();
		this.projects = projects;
		this.location = location;
		this.options = options;
	}

	@Override
	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		IProgressMonitor subMonitor = EclipseBazaarCore.subProgressMonitorFor(monitor);
		try {
			int totalwork = 1000;
			subMonitor.beginTask(CoreTexts.PullCommand_taskName, totalwork);
			Map<IBzrBranch, List<IProject>> map = getProjectsByBranch(projects);
			for (IBzrBranch branch : map.keySet()) {
				IBazaarClient client = getClient(branch);
				subMonitor.worked(totalwork/map.get(branch).size());
                client.merge(location, options);
			}
			return projects;
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, projects[0]);
		} finally {
			subMonitor.done();
		}
	}
	
	@Override
	protected int getChangeType() {
		for (Option option : options) {
			if(option.equals(IMergeOptions.PULL)) {
				return BzrChangeStateEvent.BRANCH_STATE_MODIFY;
			}
		}
		return BzrChangeStateEvent.RESOURCE_MODIFY;
	}
}
