/**
 * 
 */
package org.vcs.bazaar.eclipse.core.commands;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IWorkspaceRunnable;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.listeners.BzrChangeStateEvent;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.core.utils.ResourceUtil;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 * 
 */
public abstract class MetaModifyCommand extends BazaarCommand {

	public void run(IProgressMonitor monitor) throws BazaarException {
		final IResource[] resources = execute(monitor);
		ResourceUtil.cleanCache(resources);
		IProgressMonitor subMonitor = EclipseBazaarCore.subProgressMonitorFor(monitor);
		try {
			ResourcesPlugin.getWorkspace().run(new IWorkspaceRunnable() {
				public void run(IProgressMonitor monitor) throws CoreException {
					List<IResource> resourceToRefresh = new ArrayList<IResource>(resources.length);
					for (IResource resource : resources) {
						if(resource.exists()) {
							if(resource.isSynchronized(IResource.DEPTH_INFINITE)) {
								resource.touch(monitor);
							} else {
								resource.refreshLocal(IResource.DEPTH_INFINITE, monitor);
							}
							ResourceUtil.markAsDirty(resource);
						}
						if(resource.getType() == IResource.PROJECT)
							resourceToRefresh.addAll(Arrays.asList(resource.getProject().members(IProject.EXCLUDE_DERIVED)));
						else
							resourceToRefresh.add(resource);
					}
					BzrChangeStateEvent event = new BzrChangeStateEvent(this, resourceToRefresh, getChangeType());
					EclipseBazaarCore.broadcastModificationStateChanges(event);
				}			
			}, subMonitor);
		} catch (CoreException e) {
			throw BazaarException.wrapException(e);
		} finally {
			subMonitor.done();
			monitor.done();
		}
	}

	public abstract IResource[] execute(IProgressMonitor monitor) throws BazaarException;
	
	protected abstract int getChangeType();

	// helpers
	protected static IResource[] getIResources(IBzrLocalResource[] bzrResources) {
		List<IResource> resources = new ArrayList<IResource>(bzrResources.length);
		for (IBzrLocalResource resource : bzrResources) {
			resources.add(resource.getIResource());
		}
		return resources.toArray(new IResource[0]);
	}

	protected static IResource[] getIResources(List<IBzrLocalResource> bzrResources) {
		return getIResources(bzrResources.toArray(new IBzrLocalResource[0]));
	}

}
