/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.syntax.IPullOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class PullCommand extends StateChangeCommand {

	private IProject project;
	private IBzrBranch location;
	private boolean remember = false;

	public PullCommand(IProject project, IBzrBranch location) {
		this.project = project;
		this.location = location;
	}

	@Override
	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		IProgressMonitor subMonitor = EclipseBazaarCore.subProgressMonitorFor(monitor);
		try {
			int totalwork = 100;
			subMonitor.beginTask(CoreTexts.PullCommand_taskName, totalwork);
			IBazaarClient client = getClient(project);
			subMonitor.worked(totalwork/2);
			if(remember)
				client.pull(location.getBranchLocation(), IPullOptions.REMEMBER);
			else 
				client.pull(location.getBranchLocation());
			subMonitor.worked(totalwork/2);
			return new IResource[] { project };
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, project);
		} finally {
			subMonitor.done();
		}
	}

	public void setRemember(boolean remember) {
		this.remember = remember;
	}

}
