/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.commandline.syntax.IPushOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class PushCommand extends BazaarCommand {

	private IProject project;
	private BranchLocation location;
	private boolean remember;
	private boolean useExsitingDir;

	public PushCommand(IProject project, BranchLocation location) {
		this.project = project;
		this.location = location;
	}

	public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			IBazaarClient client = getClient(project);
			List<Option> options = new ArrayList<Option>(0);
			if(remember) {
				options.add(IPushOptions.REMEMBER);
			} if(useExsitingDir) {
				options.add(IPushOptions.USE_EXISTING_DIR);
			}
			client.push(location, options.toArray(new Option[options.size()]));
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, project);
		} finally {
			monitor.done();
		}
	}

	public void setRemember(boolean remember) {
		this.remember = remember;
	}

	public void setUseExsitingDir(boolean useExsitingDir) {
		this.useExsitingDir = useExsitingDir;
	}

}
