/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import java.io.File;
import java.util.List;
import java.util.Map;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.syntax.IRemoveOptions;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class RemoveCommand extends ResourceChangeCommand {

	private IBzrLocalResource[] resources;

	public RemoveCommand(IBzrLocalResource[] bzrResources) {
		this.resources = bzrResources;
	}

	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		Map<IProject, List<File>> map = getFilesByProjectMap(resources);
		try {
			monitor.beginTask(CoreTexts.RemoveCommand_removing, resources.length);
			for (IProject project : map.keySet()) {
				IBazaarClient client = getClient(project);
				client.remove(map.get(project).toArray(new File[0]), IRemoveOptions.KEEP);
			}
			return getIResources(resources);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

}
