/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class RevertCommand extends ResourceChangeCommand {
	private List<IBzrLocalResource> resources;
	private Option[] options;
	private boolean revertBranch;
	
	/**
	 * 
	 * @param revertBranch 
	 * @param bzrResources 
	 * 				a list of IBzrResource that can belongs to different branches
	 */
	public RevertCommand(List<IBzrLocalResource> resourcesToRevert, boolean revertBranch, Option[] options) {
		super();
		this.resources = resourcesToRevert;
		this.options = options;
		this.revertBranch = revertBranch;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.vcs.bazaar.eclipse.core.commands.IBazaarCommand#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	@Override
	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		Map<IBzrBranch, List<File>> map = getFilesByBranchMap(resources);
		try {
			monitor.beginTask(CoreTexts.RevertCommand_taskName, resources.size());
			for (IBzrBranch branch : map.keySet()) {
				BazaarTeamProvider provider = BzrWorkspaceRoot.getProviderFor(branch.getProject());
				IBazaarClient client = provider.getBzrWorkspaceRoot().getClient();
				if(revertBranch) {
					client.revert(new File[]{branch.getFile()}, options);
				} else {
					client.revert(map.get(branch).toArray(new File[0]), options);
				}
			}
			List<IResource> resourcesToRefresh= new ArrayList<IResource>(resources.size());
			for (IBzrLocalResource bzrResource : resources) {
				resourcesToRefresh.add(bzrResource.getIResource());
				if(bzrResource.getIResource().getType() != IResource.PROJECT) {
					resourcesToRefresh.add(bzrResource.getIResource().getParent());
				}
			}
			return resourcesToRefresh.toArray(new IResource[0]);
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

}
