/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class RevnoCommand extends BazaarCommand {

	private IResource resource;
	private BazaarRevision revision;

	public RevnoCommand(IResource resource) {
		this.resource = resource;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.vcs.bazaar.eclipse.core.commands.IBazaarCommand#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.RevnoCommand_taskName, 1000);
			IBazaarClient client = getClient(resource.getProject());
			client.getNotificationHandler().disableLog();
			revision = client.revno(resource.getLocation().toFile());
			client.getNotificationHandler().enableLog();
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, resource);
		} finally {
			monitor.done();
		}
	}

	public BazaarRevision getRevision() {
		return revision;
	}

}
