/**
* Copyright (C) 2009 Canonical Ltd
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarAnnotation;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.client.core.BranchLocation;

/**
 * @author Javier Der Derian<javierder AT gmail DOT com>
 * @BasedOn RevertCommand from BzrEclipse
 * 
 */
public class SendCommand extends BazaarCommand {

	private final IBzrLocalResource resource;
	private IBazaarAnnotation annotation;
	private Option[] options;
	private BranchLocation branchLocation;


	public SendCommand(IBzrLocalResource bzrResource, Option[] options, BranchLocation branchLocation) {
		this.resource = bzrResource;
		this.options = options;
		this.branchLocation = branchLocation;
	}

	/**
	 * 
	 * @see org.vcs.bazaar.eclipse.core.commands.IBazaarCommand#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public void run(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.SendCommand_send, 1000);
			IBazaarClient client = getClient(resource.getIResource().getProject());
						
			client.send(branchLocation, options);
			
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, resource.getIResource());
		} finally {
			monitor.done();
		}
	}

	public IBazaarAnnotation getAnnotation() {
		return annotation;
	}

}
