/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * TODO: should check here if the project is lightweight/heavyweight checkout?
 */
public class SwitchCommand extends StateChangeCommand {

	private IProject project;
	private IBzrBranch branch;

	public SwitchCommand(IProject project, IBzrBranch branch) {
		this.project = project;
		this.branch = branch;
	}

	@Override
	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask("Switch command", 1000);
			IBazaarClient client = getClient(project);
			client.switchBranch(branch.getBranchLocation());
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e, project);
		} finally {
			monitor.done();
		}
		return new IResource[]{project};
	}

}
