/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.commands;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.client.core.BazaarClientException;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class UnCommitCommand extends StateChangeCommand {

	private IProject[] projects;

	public UnCommitCommand(IProject[] projects) {
		this.projects = projects;
	}

	public IResource[] execute(IProgressMonitor monitor) throws BazaarException {
		try {
			monitor.beginTask(CoreTexts.UnCommitCommand_unCommiting, projects.length * 100);
			for (IProject project : projects) {
				BzrWorkspaceRoot root = BzrWorkspaceRoot.getBzrWorkspaceRootFor(project);
				root.getClient().unCommit(root.getBranch().getPath().toFile());
			}
			return projects;
		} catch (BazaarClientException e) {
			throw BazaarException.wrapException(e);
		} finally {
			monitor.done();
		}
	}

}
