/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.history;

import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.SortedMap;
import java.util.TreeMap;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.team.core.RepositoryProvider;
import org.eclipse.team.core.history.IFileRevision;
import org.eclipse.team.core.history.provider.FileHistory;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.IBazaarLogMessage;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;

/**
 * 
 * @author Guillermo Gonzalez
 *
 */
public class BazaarFileHistory extends FileHistory {
	private IFile file;

	protected SortedMap<BazaarRevision, BazaarFileRevision> revisionMap;
	protected List<IBazaarLogMessage> logMessages;

	public BazaarFileHistory(IFile file) {
		super();
		this.file = file;
	}

	public IFileRevision[] getContributors(IFileRevision revision) {
		final BazaarFileRevision bazaarRevision = (BazaarFileRevision) revision;
		final List<IBazaarLogMessage> merged = bazaarRevision.getIBazaarLogMessage().getMerged();
		if (merged != null && merged.size() > 0) {
			final List<IFileRevision> revisions = new ArrayList<IFileRevision>(merged.size());
			for (IBazaarLogMessage mergeLog : merged) {
				revisions.add(new BazaarFileRevision(mergeLog, file));
			}
			return revisions.toArray(new IFileRevision[revisions.size()]);
		} else {
			return new IFileRevision[]{revisionMap.get(bazaarRevision.getIBazaarLogMessage().getRevision())};
		}
	}

	public IFileRevision getFileRevision(String id) {
		System.out.println("BazaarFileHistory::getFileRevision(" + id + ")");
		return null;
	}

	public IFileRevision[] getFileRevisions() {
		return revisionMap.values().toArray(new IFileRevision[0]);
	}

	public IFileRevision[] getTargets(IFileRevision revision) {
		System.out.println("BazaarFileHistory::getTargets()");
		return null;
	}

	public void refresh(IProgressMonitor monitor) throws CoreException {
		RepositoryProvider provider = RepositoryProvider.getProvider(file.getProject());
		if (provider != null && provider instanceof BazaarTeamProvider) {
			monitor.subTask("Fetching log messages...");
			logMessages = EclipseBazaarCore.getDefault().getLogCacheManager().getLogs(file);
			monitor.worked(500);
			if(revisionMap == null)
				revisionMap = new TreeMap<BazaarRevision, BazaarFileRevision>(new Comparator<BazaarRevision>() {
					public int compare(BazaarRevision rev1, BazaarRevision rev2) {
						return rev1.compareTo(rev2);
					}					
				});
			else 
				revisionMap.clear();
			for (IBazaarLogMessage log : logMessages) {
				revisionMap.put(log.getRevision(), new BazaarFileRevision(log, file));
			}
		}
		monitor.worked(300);
	}

}
