/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.history;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IStorage;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.team.core.history.IFileRevision;
import org.eclipse.team.core.history.provider.FileRevision;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.IBazaarLogMessage;
import org.vcs.bazaar.eclipse.core.resources.IStorageBazaarRevision;

/**
 * 
 * @author Guillermo Gonzalez
 *
 */
public class BazaarFileRevision extends FileRevision {
	IFile file;

	IBazaarLogMessage logMessage;

	IStorageBazaarRevision storageBazaarRevision;
	
	BazaarFileRevision parent;

	public BazaarFileRevision(IBazaarLogMessage logMessage, IFile resource) {
		super();
		this.logMessage = logMessage;
		this.file = resource;
	}

	public BazaarFileRevision(IBazaarLogMessage mergedLog, IFile resource, BazaarFileRevision parentRevision) {
		this(mergedLog, resource);
		this.parent = parentRevision;
	}

	public IBazaarLogMessage getIBazaarLogMessage() {
		return logMessage;
	}

	public String getName() {
		return file.getName();
	}

	public String getContentIdentifier() {
		return logMessage.getRevision().getValue();
	}

	public IStorage getStorage(IProgressMonitor monitor) throws CoreException {
		if (storageBazaarRevision == null) {
			storageBazaarRevision = new IStorageBazaarRevision(file, logMessage.getRevision());
		}
		return storageBazaarRevision;
	}

	public boolean isPropertyMissing() {
		return false;
	}

	public IFileRevision withAllProperties(IProgressMonitor monitor) throws CoreException {
		return null;
	}

	public IFile getIFile() {
		return file;
	}
	
	public BazaarFileRevision[] getChildren() {
		List<BazaarFileRevision> childs = new ArrayList<BazaarFileRevision>();
		if(logMessage.getMerged() != null && logMessage.getMerged().size() > 0) {
			for (IBazaarLogMessage mergedLog : logMessage.getMerged()) {
				childs.add(new BazaarFileRevision(mergedLog, getIFile(), this));	
			}
		}
		return childs.toArray(new BazaarFileRevision[0]);
	}
	
	public boolean hasChildren() {
		return logMessage.getMerged() != null && logMessage.getMerged().size() > 0;
	}
	
	public boolean hasParent() {
		return parent != null;
	}

	public BazaarFileRevision getParent() {
		return parent;
	}
	
	public BazaarRevision getRevision() {
		return logMessage.getRevision();
	}

	public int compareRevisionTo(BazaarFileRevision other) {
		if(other != null)
			return logMessage.getRevision().compareTo(other.getRevision());
		return 1;
	}
	
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((getRevision() == null) ? 0 : getRevision().hashCode());
		result = prime * result + ((parent == null) ? 0 : parent.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		final BazaarFileRevision other = (BazaarFileRevision) obj;
		if (parent == null) {
			if (other.parent != null)
				return false;
		} else if (!parent.equals(other.parent))
			return false;
		if (getRevision() == null) {
			if (other.getRevision() != null)
				return false;
		} else if (!getRevision().equals(other.getRevision()))
			return false;
		return true;
	}

	
	
}
