/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.inventory;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * Cache for storing and retrieving inventory info
 * 
 */
public interface IInventoryCache {

	/**
	 * Get if the given resource is in the inventory (which does not need to exist)
	 * 
	 * @param resource
	 * @return LocalResourceStatus
	 */
	Boolean isInInventory(IResource resource);

	/**
	 * Add a resource (which does not need to exist)
	 * 
	 * @param status -
	 *            can be null
	 * @return resource for which the status was cached
	 */
	IResource add(IResource status);

	/**
	 * Remove the given resource from the cache
	 * 
	 * @param resource
	 * @return
	 */
	IResource remove(IResource resource);
	
	/**
	 * Tells if a given resource expired from the cache
	 * @param project
	 * @return
	 */
	Boolean needRefresh(IResource resource);

	/**
	 * Purge (remove) the information from the cache.
	 * 
	 * @param root
	 * @param deep
	 * @throws CoreException
	 * @throws BazaarException
	 */
	void purgeCache(IContainer root, boolean deep) throws BazaarException, CoreException;

}