/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.inventory;

import java.util.List;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.ITracingOptions;
import org.vcs.bazaar.eclipse.core.commands.LsCommand;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;

/**
 * When the is asked if a resource is in the inventory, we don't update a resource 
 * at once.<br>
 * 
 * @author Guillermo Gonzalez
 */
public class InventoryUpdater {

	public InventoryUpdater() {
		super();
	}

	/**
	 * Returns a list of resources under bazaar control of the given resource and it's children
	 * If the resource is a FILE the update is executed on it's parent
	 * 
	 * @param resource
	 * @param monitor 
	 * @return
	 * @throws CoreException
	 */
	protected List<IBzrLocalResource> resourceToUpdate(IResource resource, IProgressMonitor monitor) throws CoreException {
		IProgressMonitor subMonitor = EclipseBazaarCore.subProgressMonitorFor(monitor);
		EclipseBazaarCore.trace(ITracingOptions.INVENTORY_COMMAND, "InventoryUpdater.resourceToUpdate: " + resource.getName());
		// get the inventory of the parent
		IResource resourceToUpdate = resource;
		if(resource.getType() == IResource.FILE) {
			resourceToUpdate = resource.getParent();
		}
		LsCommand cmd = new LsCommand(resourceToUpdate, false);
		cmd.run(subMonitor);
		return cmd.getResources();
	}

}
