package org.vcs.bazaar.eclipse.core.model;

import java.net.URI;

/**
 * <p>
 * The analog of file system files and directories. This could be to a remote
 * resource or a local resource.
 * </p>
 * 
 * @see IBzrFolder
 * @see IBzrFile
 */
public interface IBzrResource extends IBzrObject {

	/**
	 * Answers the name of the resource.
	 * 
	 * @return the name of the resource this handle represents. It can never be
	 *         <code>null</code>.
	 */
	String getName();

	String getBranchRelativePathAsString();


	/**
	 * Answers if the handle is a file or a folder handle.
	 * 
	 * @return <code>true</code> if this is a folder handle and
	 *         <code>false</code> if it is a file handle.
	 */
	boolean isFolder();

	/**
	 * Answers the local relative path from the given ancestor to the receiver..
	 * @param ancestor
	 * @return the ancestor relative path for this resource.
	 */
	String getRelativePath(IBzrResource ancestor);

	/**
	 * Give the folder that contains this resource. If the resource is not
	 * managed then the stdout of the operation is not specified.
	 * 
	 * @return a handle to the parent of this resource.
	 */
	IBzrResource getParent();

	/**
	 * @return boolean
	 */
	boolean exists();
	
	int hashCode();
	
	boolean equals(Object obj);
	
	URI getLocation();

}
