/**
 * 
 */
package org.vcs.bazaar.eclipse.core.model.local;

import java.io.File;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.model.IBzrResource;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public interface IBzrLocalResource extends IBzrResource {

	
	/**
	 * 
	 * @return boolean
	 */
	boolean isDirty();
	
	/**
	 * 
	 * @return
	 * @throws CoreException
	 */
	IBzrResourceStatus getStatus() throws CoreException;
	
	/**
	 * 
	 * @param monitor
	 * @return
	 * @throws BazaarException
	 */
	boolean isModified(IProgressMonitor monitor) throws BazaarException;
	
	/**
	 * Deletes the resource represented by the handle.
	 * @throws BazaarException
	 */
	void delete() throws BazaarException;

	/**
	 * Moves the resource represented by the handle.
	 * @param destination
	 * @throws BazaarException
	 */
	void move(IPath destination) throws BazaarException;
	
	/**
	 * @return BzrWorkspaceRoot which this resource belongs
	 */
	BzrWorkspaceRoot getBzrWorkspaceRoot();
	
	File getFile();

	boolean isProject();
	
	/**
	 * Answers if this resource is under version control
	 * @return true if the resource is managed
	 * @throws BazaarException
	 */
	boolean isManaged() throws BazaarException;

	/**
	 * Unmanage the given resource
	 * @param monitor
	 * @throws BazaarException
	 */
	void unmanage(IProgressMonitor monitor) throws BazaarException;
	
	/**
	 * 
	 * @return IPath containing the relative path to the branch root
	 */
	IPath getBranchRelativePath();
	
	/**
	 * Answer the underlying IResource.
	 * 
	 * @return the IResource that corresponds to the CVS resource
	 */
	IResource getIResource();
}
