/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.repository;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectNature;
import org.eclipse.core.resources.IResourceRuleFactory;
import org.eclipse.core.resources.team.IMoveDeleteHook;
import org.eclipse.core.resources.team.ResourceRuleFactory;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.QualifiedName;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.team.core.RepositoryProvider;
import org.eclipse.team.core.history.IFileHistoryProvider;
import org.eclipse.team.core.history.provider.FileHistoryProvider;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.history.BazaarHistoryProvider;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProviderType.BackgroundJob;
import org.vcs.bazaar.eclipse.core.resources.BazaarMoveDeleteHook;
import org.vcs.bazaar.eclipse.core.utils.ResourceUtil;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author zingo
 * @modifiedBy Guillermo Gonzalez
 * 
 */
public class BazaarTeamProvider extends RepositoryProvider {

	public static final String ID = "org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider";
	public static final QualifiedName NAME = new QualifiedName(ID, "bzr-team-provider");
	public static final QualifiedName BRANCH_ROOT_PATH = new QualifiedName(ID, "path");
	private static final ResourceRuleFactory RESOURCE_RULE_FACTORY = new ResourceRuleFactory() {};
	
	private BzrWorkspaceRoot bzrWorkspaceRoot;
	private final FileHistoryProvider fileHistoryProvider = new BazaarHistoryProvider();

	public static void registerProject(IProject project, IPath metaFolderPath) throws CoreException {
		RepositoryProvider.map(project, ID);
	}

	public BazaarTeamProvider() {
		super();
	}
	
	public String getID() {
		return getClass().getName();
	}

	public void configureProject() {
		// FIXME: this should be called by BazaarTemProviderType "automatically"
		if (ResourceUtil.isUnderBazaarScope(getProject())) {
			Job job = new BackgroundJob(CoreTexts.BazaarTeamProviderType_backgroundJobName, getProject());
			job.schedule();
		}
	}

	public void deconfigure() throws CoreException {
		getProject().setPersistentProperty(BRANCH_ROOT_PATH, null);
	}
	
	@Override
	protected void deconfigured() {
		super.deconfigured();
		bzrWorkspaceRoot = null;
	}

	/**
	 * @see IProjectNature#setProject(IProject)
	 */
	public void setProject(IProject project) {
		super.setProject(project);
		bzrWorkspaceRoot = new BzrWorkspaceRoot(project);
		// Set up a connection to the Bazaar client
		try {
		    // FIXME: Can we do this somewhere else where there is proper error handling?
		    // configureProject() isn't called on startup, so that doesn't work.
		    bzrWorkspaceRoot.getClient();
		} catch (BazaarException e) {
		    // FIXME: Log this exception
		}
	}

	public IMoveDeleteHook getMoveDeleteHook() {
		return new BazaarMoveDeleteHook();
	}
	
	public IFileHistoryProvider getFileHistoryProvider() {
		return fileHistoryProvider;
	}

	@Override
	public IResourceRuleFactory getRuleFactory() {
		return RESOURCE_RULE_FACTORY;
	}
	
	@Override
	public boolean canHandleLinkedResourceURI() {
		return true;
	}
	
	// Convenience methods
	public IBzrBranch getBranch() {
		return this.bzrWorkspaceRoot.getBranch();
	}

	public BzrWorkspaceRoot getBzrWorkspaceRoot() {
		return this.bzrWorkspaceRoot;
	}

	public IBazaarClient getClient() throws BazaarException {
		return this.bzrWorkspaceRoot.getClient();
	}

}
