/*******************************************************************************
 * Copyright (c) 2006 Software Balm Consulting Inc.
 * 
 * TODO: LICENSE DETAILS
 *******************************************************************************/
package org.vcs.bazaar.eclipse.core.repository;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.Iterator;
import java.util.Set;
import java.util.SortedSet;
import java.util.TreeSet;

import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;

/*
 * A manager for all Bazaar repository locations.
 * 
 * TODO: Need a way to delete these branches. Repo Explorer perspective a la
 * subclipse? TODO: Should probably use a text based format for the locations.
 * This is just a crude object dump right now.
 */
public class BranchLocationManager {
	private static final SortedSet<IBzrBranch> branches = new TreeSet<IBzrBranch>();// final ensures that its reference will remain the same.
	private static final String BRANCH_LOCATION_FILE = "repo_locations.txt";
	
	
	//This will only get instantiated once don't need to synchronize the constructor.
	private static final BranchLocationManager instance = new BranchLocationManager();

	private BranchLocationManager(){}
	/**
	 * @return The manager instance
	 */
	public static BranchLocationManager getInstance() {		
		return instance;
	}

	/*
	 * Return a <code>File</code> object representing the location file. The
	 * file may or may not exist and must be checked before use.
	 */
	private File getLocationFile() {
		return EclipseBazaarCore.getDefault().getStateLocation().append(BRANCH_LOCATION_FILE).toFile();
	}

	/*
	 * Load all saved repository locations from the plug-in's default area.
	 */
	public void start() throws Exception {

		File locationFile = getLocationFile();

		// If the file doesn't exist, then there's nothing to do.
		if (!locationFile.exists())
			return;

		FileInputStream istream = new FileInputStream(locationFile);
		ObjectInputStream p = new ObjectInputStream(istream);

		try {
			while (true) {
				// String uri = (String) p.readObject();
				IBzrBranch branch = (IBzrBranch) p.readObject();
				addRepoLocation(branch);
			}
		} catch (IOException e) {
			// Expected exception when there are no more records. Is this the only reason for an ioexception ??
		} finally {
			p.close();
			istream.close();
		}
	}

	/*
	 * Flush all repository locations out to a file in the plug-in's default
	 * area.
	 */
	public void stop() throws Exception {
		// Determine if there's anything that we need to save out to file.
		if (getAllBranches().size() == 0)
			return;

		File locationFile = getLocationFile();

		// If the file doesn't exist, then create it.
		if (!locationFile.exists()) {
			locationFile.createNewFile();
		}

		FileOutputStream ostream = new FileOutputStream(locationFile);
		ObjectOutputStream p = new ObjectOutputStream(ostream);

		// Add any previously existing URI's to the combo box for ease of use.
		Iterator<IBzrBranch> iter = getAllBranches().iterator();
		while (iter.hasNext()) {
			IBzrBranch branch = ((IBzrBranch) iter.next());
			p.writeObject(branch);

		}

		p.flush();
		ostream.close();
	}

	/*
	 * Return an ordered list of all repository locations that are presently
	 * known.
	 */
	public Set<IBzrBranch> getAllBranches() {
		return branches;
	}

	/*
	 * Add a repository location to the database.
	 */
	public boolean addRepoLocation(IBzrBranch branch) {
		return branches.add(branch);
	}

}
