/*******************************************************************************
 * Copyright (c) 2005, 2006 Subclipse project and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Subclipse project committers - initial API and implementation
 ******************************************************************************/
package org.vcs.bazaar.eclipse.core.status;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * Cache for storing and retrieving local status info
 * 
 */
public interface IStatusCache {

	/**
	 * @param resource
	 * @return true when the resource's status is present in cache
	 */
	boolean hasCachedStatus(IResource resource);

	/**
	 * Get the status of the given resource (which does not need to exist)
	 * 
	 * @param resource
	 * @return LocalResourceStatus
	 */
	IBzrResourceStatus getStatus(IResource resource);

	/**
	 * Add a status for its resource (which does not need to exist)
	 * 
	 * @param status -
	 *            can be null
	 * @return resource for which the status was cached
	 */
	IResource addStatus(IBzrResourceStatus status);

	/**
	 * Remove status of the given resource from the cache
	 * 
	 * @param resource
	 * @return
	 */
	IResource removeStatus(IResource resource);

	/**
	 * Purge (remove) the status information from the cache.
	 * 
	 * @param root
	 * @param deep
	 * @throws CoreException
	 * @throws SVNException
	 */
	void purgeCache(IContainer root, boolean deep) throws BazaarException, CoreException;

	/**
	 * Flush (pending) statuses which were not saved yet due to e.g. locked
	 * workspace
	 */
	void flushPendingStatuses();
}