/**
 * 
 */
package org.vcs.bazaar.eclipse.core.status;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IResourceVisitor;
import org.eclipse.core.runtime.CoreException;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 * 
 */
public class NaiveCache implements IStatusCache {
	private final Map<IResource, IBzrResourceStatus> statusMap = new HashMap<IResource, IBzrResourceStatus>();
	/** contains the resource and the time (in seconds) of the last modification */
	private final Map<IResource, Long> lastUpdateMap = new HashMap<IResource, Long>();

	public IResource addStatus(IBzrResourceStatus status) {
		statusMap.put(status.getResource().getIResource(), status);
		lastUpdateMap.put(status.getResource().getIResource(), status.getResource().getIResource().getModificationStamp());
		return status.getResource().getIResource();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.vcs.bazaar.eclipse.core.status.IStatusCache#flushPendingStatuses()
	 */
	public void flushPendingStatuses() {
		// TODO Auto-generated method stub
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.vcs.bazaar.eclipse.core.status.IStatusCache#getStatus(org.eclipse.core.resources.IResource)
	 */
	public IBzrResourceStatus getStatus(IResource resource) {
		IBzrResourceStatus status = statusMap.get(resource);
		if (status != null) {
			Long lastUpdate = lastUpdateMap.get(resource);
			if(lastUpdate != null && resource.getModificationStamp() - lastUpdate != 0)
				return null;
		}
		return status;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.vcs.bazaar.eclipse.core.status.IStatusCache#hasCachedStatus(org.eclipse.core.resources.IResource)
	 */
	public boolean hasCachedStatus(IResource resource) {
		// return false if the cache time expired
		if (statusMap.get(resource) != null) {
			Long lastUpdate = lastUpdateMap.get(resource);
			return (lastUpdate != null && resource.getModificationStamp() - lastUpdate == 0);
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.vcs.bazaar.eclipse.core.status.IStatusCache#purgeCache(org.eclipse.core.resources.IContainer,
	 *      boolean)
	 */
	public void purgeCache(IContainer root, boolean deep) throws CoreException {
		root.accept(new IResourceVisitor() {
			public boolean visit(IResource resource) throws CoreException {
				removeStatus(resource);
				return true;
			}
		});
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.vcs.bazaar.eclipse.core.status.IStatusCache#removeStatus(org.eclipse.core.resources.IResource)
	 */
	public IResource removeStatus(IResource resource) {
		statusMap.remove(resource);
		lastUpdateMap.remove(resource);
		return resource;
	}

}
