/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.status;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.ITracingOptions;
import org.vcs.bazaar.eclipse.core.commands.StatusCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;

/**
 * When the status of a resource is asked, we don't update a resource at once.<br>
 * Based on StatusUpdateStrategy from Subclipse<br>
 * 
 * @author Guillermo Gonzalez
 */
public class StatusUpdater {

	public StatusUpdater() {
		super();
	}

	/**
	 * update the status of the given resource or it's parent (if the resource
	 * is a File)
	 * 
	 * @param resource
	 * @param monitor 
	 * @return
	 * @throws CoreException
	 */
	protected IBzrResourceStatus[] statusesToUpdate(IResource resource, IProgressMonitor monitor) throws CoreException {
		IProgressMonitor subMonitor = EclipseBazaarCore.subProgressMonitorFor(monitor);
		EclipseBazaarCore.trace(ITracingOptions.STATUS_COMMAND, "StatusUpdater.statusesToUpdate: " + resource.getProject().getName()+ "/" +resource.getName());
		// we update the parent and its immediate children
		IResource resourceToUpdate = resource;
		if ((resource.getType() == IResource.FILE)) {
			resourceToUpdate = resource.getParent();
		}
		// don't do getRepository().getSVNClient() as we can ask the status of a
		// file that is not associated with a known repository
		// we don't need login & password so this is not a problem
		IBzrResourceStatus[] statuses = null;
		StatusCommand cmd = new StatusCommand(resourceToUpdate.getProject(), BzrWorkspaceRoot.getBzrResourceFor(resourceToUpdate));
		cmd.run(subMonitor);
		statuses = cmd.getStatus();
		return statuses;
	}

}
