/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.subscriber;

import java.io.BufferedInputStream;

import org.eclipse.core.resources.IStorage;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.team.core.TeamException;
import org.eclipse.team.core.variants.CachedResourceVariant;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class BazaarResourceVariant extends CachedResourceVariant {

	private IStorage storage;
	private byte[] bytes;

	public BazaarResourceVariant(IStorage file) {
		super();
		this.storage = file;
	}

	public BazaarResourceVariant(IStorage file, byte[] bytes) {
		super();
		this.storage = file;
		this.bytes = bytes;
	}

	@Override
	protected void fetchContents(IProgressMonitor monitor) throws TeamException {
		try {
			setContents(new BufferedInputStream(storage.getContents()), monitor);
		} catch (CoreException e) {
			throw TeamException.asTeamException(e);
		}
	}

	@Override
	protected String getCacheId() {
		return EclipseBazaarCore.getPluginId();
	}

	@Override
	protected String getCachePath() {
		return storage.getFullPath().toString() + "_" + getContentIdentifier(); //$NON-NLS-1$
	}

	public byte[] asBytes() {
		if (bytes == null) {
			bytes = getCachePath().getBytes();
		}
		return bytes;
	}

	public String getContentIdentifier() {
		return String.valueOf(storage.getFullPath().toFile().lastModified());
	}

	public String getName() {
		return storage.getName();
	}

	public boolean isContainer() {
		return storage.getFullPath().toFile().isDirectory();
	}

}
