/**
 * LICENCSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.core.subscriber;

import static org.vcs.bazaar.eclipse.core.utils.ResourceUtil.shouldHandle;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IStorage;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.team.core.RepositoryProvider;
import org.eclipse.team.core.TeamException;
import org.eclipse.team.core.subscribers.Subscriber;
import org.eclipse.team.core.synchronize.SyncInfo;
import org.eclipse.team.core.variants.IResourceVariantComparator;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.resources.IStorageBazaarRevision;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class BazaarStatusSuscriber extends Subscriber {

	private static final String NAME = "BazaarStatusSuscriber";

	private final BazaarLocalVariantComparator comparatorObj = new BazaarLocalVariantComparator();

	private static final BazaarStatusSuscriber instance = new BazaarStatusSuscriber();

	public static BazaarStatusSuscriber getInstance(){
		return instance;
	}

	private BazaarStatusSuscriber() {}

	public String getName() {
		return NAME;
	}

	public boolean isSupervised(IResource resource) throws TeamException {
		// TODO: check if this resource is .bzr
		return shouldHandle(resource);
	}

	public IResource[] members(IResource resource) throws TeamException {
		try {
			if (resource.getType() == IResource.FILE)
				return new IResource[0];
			final IContainer container = (IContainer) resource;
			final List<IResource> existingChildren = new ArrayList<IResource>(Arrays.asList(container.members()));
			existingChildren.addAll(Arrays.asList(container.findDeletedMembersWithHistory(IResource.DEPTH_INFINITE, null)));
			return (IResource[]) existingChildren.toArray(new IResource[existingChildren.size()]);
		} catch (CoreException e) {
			throw TeamException.asTeamException(e);
		}
	}

	public IResource[] roots() {
		final List<IProject> result = new ArrayList<IProject>();
		final IProject[] projects = ResourcesPlugin.getWorkspace().getRoot().getProjects();
		for (IProject project : projects) {
			if (project.isAccessible()) {
				final RepositoryProvider provider = RepositoryProvider.getProvider(project, EclipseBazaarCore.getProviderID());
				if (provider != null) {
					result.add(project);
				}
			}
		}
		return result.toArray(new IProject[result.size()]);
	}

	public SyncInfo getSyncInfo(IResource resource) throws TeamException {
		// TODO: is ok to pass both as null?
		return getSyncInfo(resource, null, null);
	}

	public SyncInfo getSyncInfo(IResource resource, IStorage base, IStorage remote) throws TeamException {
		try {			
			if (base == null)
				base = new IStorageBazaarRevision(resource, BazaarRevision.getRevision(BazaarRevision.Prefix.LAST, "1"));
			
			final BazaarResourceVariant baseFileHist = new BazaarResourceVariant(base);
			BazaarResourceVariant remoteFileHist = null;
			if (remote != null) {
				remoteFileHist = new BazaarResourceVariant(remote);
			}
			final SyncInfo info = new SyncInfo(resource, baseFileHist, remoteFileHist, comparatorObj);
			info.init();
			return info;
		} catch (CoreException e) {
			throw BazaarException.wrapException(e);
		}
	}

	public IResourceVariantComparator getResourceComparator() {
		return comparatorObj;
	}

	public void refresh(IResource[] resources, int depth, IProgressMonitor monitor) throws TeamException {
	// TODO: implement me

	}

}
