package org.vcs.bazaar.eclipse.core.utils;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.IJobStatus;
import org.eclipse.core.runtime.jobs.Job;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;

/**
 * A Implementation of IStatus that allows to store arbritary objects.
 *  
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class BzrJobStatus<T> extends Status implements IJobStatus {
	
	private Job job;
	private T result;

	/**
	 * Creates a new job status with no interesting error code or exception.
	 * @param severity
	 * @param job
	 * @param message
	 */
	public BzrJobStatus(int severity, Job job, String message) {
		super(severity, EclipseBazaarCore.getPluginId(), 1, message, null);
		this.job = job;
	}
	
	public BzrJobStatus(int severity, Job job, T result, String message) {
		super(severity, EclipseBazaarCore.getPluginId(), 1, message, null);
		this.result = result;
		this.job = job;
	}

	public Job getJob() {
		return job;
	}
	
	public static IJobStatus OK(Job job, Object result, String message) {
		BzrJobStatus status = new BzrJobStatus(IJobStatus.OK, job, message);
		status.result = result;
		return status;
	}
	
	public static IJobStatus ERROR(Job job, Throwable exception, String message) {
		BzrJobStatus status = new BzrJobStatus(IJobStatus.ERROR, job, message);
		status.setException(exception);
		return status;
	}
	
	public static IStatus INFO(Job job, String message) {
		BzrJobStatus status = new BzrJobStatus(IJobStatus.INFO, job, message);
		return status;
	}
	
	public T getResult() {
		return result;
	}

}
