package org.vcs.bazaar.eclipse.core.utils;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.osgi.util.NLS;
import org.eclipse.team.core.TeamStatus;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.model.IBzrResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

public class BzrStatus extends TeamStatus implements IStatus {

	// Path for resource related status
	private IBzrResource commandRoot;

	public BzrStatus() {
		super(IStatus.OK, EclipseBazaarCore.getPluginId(), IStatus.OK, "", null, null); //$NON-NLS-N$
	}

	public BzrStatus(int severity, int code, String message, Throwable t, IResource resource) {
		super(severity, EclipseBazaarCore.getPluginId(), code, message, t, resource);
	}

	public BzrStatus(int severity, int code, String message, Throwable t) {
		super(severity, EclipseBazaarCore.getPluginId(), code, message, t, null);
	}

	public BzrStatus(int severity, int code, String message) {
		this(severity, code, message, null);
	}

	public BzrStatus(int severity, int code, IBzrResource commandRoot, String message) {
		this(severity, code, message, null);
		this.commandRoot = commandRoot;
	}

	public BzrStatus(int severity, String message, Throwable t) {
		this(severity, 0, message, t);
	}

	public BzrStatus(int severity, String message) {
		this(severity, severity, message, null);
	}

	/**
	 * @see IStatus#getMessage()
	 */
	public String getMessage() {
		String message = super.getMessage();
		if (commandRoot != null) {
			message = NLS.bind(CoreTexts.BzrStatus_messageWithRoot, new String[] { commandRoot.getName(), message });
		}
		return message;
	}

	/**
	 * Return whether this status is wrapping an internal error. An internal
	 * error is any error for which the wrapped exception is not a CVS
	 * exception. Check deeply to make sure there isn't an internal error buried
	 * deep down.
	 * 
	 * @return whether this status is wrapping an internal error
	 */
	public boolean isInternalError() {
		Throwable ex = getException();
		if (ex instanceof BazaarException) {
			BazaarException bzrEx = (BazaarException) ex;
			IStatus status = bzrEx.getStatus();
			return isInternalError(status);
		}
		return ex != null;
	}

	/**
	 * Return whether this status is wrapping an internal error. An internal
	 * error is any error for which the wrapped exception is not a CVS
	 * exception. Check deeply to make sure there isn't an internal error buried
	 * deep down.
	 * 
	 * @return whether this status is wrapping an internal error
	 */
	public static boolean isInternalError(IStatus status) {
		if (status instanceof BzrStatus) {
			return ((BzrStatus) status).isInternalError();
		}
		if (status.isMultiStatus()) {
			IStatus[] children = status.getChildren();
			for (int i = 0; i < children.length; i++) {
				IStatus child = children[i];
				if (isInternalError(child)) {
					return true;
				}
			}
			return false;
		}
		return true;
	}

	// helpers

	public void setInfo(final String message) {
		setMessage(message);
		setSeverity(IStatus.INFO);
	}

	public void setError(final String errorMessage) {
		setMessage(errorMessage);
		setSeverity(IStatus.ERROR);
	}

	public void setError(final String errorMessage, final Throwable t) {
		setError(errorMessage);
		setException(t);
	}
}
