package org.vcs.bazaar.eclipse.internal.core.model;

import java.net.URI;

import org.eclipse.core.runtime.IPath;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.IBzrResource;

/**
 * @author Guillermo Gonzalez
 *         <p>
 *         This is a class to help implementors of IBzrBranch
 *         </p>
 *         <p>
 *         <i>based on IRLDarcsRepository by Isaac Devine</i>
 *         </p>
 */
public abstract class BzrBranch extends BzrObject implements IBzrBranch {
	
	public abstract URI getLocation();

	public abstract IPath getPath();
	
	public boolean isBound() {
		return false;
	}
	
	public BranchLocation getBranchLocation() {
		return new BranchLocation(getLocation());
	}

	@Override
	public boolean equals(final Object otherRepo) {
		// make sure wrong types
		// aren't typecasted.
		if (!(otherRepo instanceof IBzrBranch)) {
			return false;
		}
		return ((IBzrBranch) otherRepo).getBranchLocation().equals(getBranchLocation());
	}

	@Override
	public int hashCode() {
		return getBranchLocation().hashCode();
	}
	
	public int compareTo(final IBzrBranch otherRepo) {
		return (otherRepo).getBranchLocation().compareTo(getBranchLocation());
	}
	
	public boolean isProjectBranch() {
		return false;
	}
	
	public IBzrBranch getBranch() {
		return this;
	}
	
	public boolean exists() {
		return getFile().exists();
	}

	public String getBranchRelativePathAsString() {
		return getLocation().toString();
	}

	public String getName() {
		return getNick();
	}

	public boolean isFolder() {
		return false;
	}
	
	public String getRelativePath(IBzrResource ancestor) {
		return getLocation().relativize(ancestor.getLocation()).toString();
	}
	
	public IBzrBranch getParent() {
		return null;
	}
	
}
