/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.internal.core.model;

import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.IBzrResource;

/**
 * @author Guillermo Gonzalez
 * 
 */
public abstract class BzrResource extends BzrObject implements IBzrResource {

	private final IBzrBranch branch;

	protected BzrResource(final IBzrBranch branch) {
		super();
		this.branch = branch;
	}
	
	public String getRelativePath(IBzrResource ancestor) {
		return ancestor.getLocation().relativize(getLocation()).toString();
	}

	public String getBranchRelativePathAsString() {
		return getRelativePath(getBranch()).toString();
	}

	@Override
	public String toString() {
		String returnValue = getBranchRelativePathAsString();
		if (returnValue == null) {
			return super.toString();
		}
		return returnValue;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((branch == null) ? 0 : branch.hashCode());
		result = prime * result + ((getLocation() == null) ? 0 : getLocation().hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		final BzrResource other = (BzrResource) obj;
		if (branch == null) {
			if (other.branch != null)
				return false;
		} else if (!branch.equals(other.branch))
			return false;
		if (getLocation() == null) {
			if (other.getLocation() != null)
				return false;
		} else if (!getLocation().equals(other.getLocation()))
			return false;
		return true;
	}

	public IBzrBranch getBranch() {
		return branch;
	}
}
