/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.internal.core.model;

import java.io.File;
import java.net.URI;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IPath;
import org.vcs.bazaar.client.core.BranchLocation;

/**
 * <p>
 * default implementation of a remote branch location.
 * </p>
 * 
 * @author Guillermo Gonzalez
 * 
 */
public class RemoteBranch extends BzrBranch {

	private static final long serialVersionUID = 959030093525213478L;

	private BranchLocation location;
	
	/**
	 * 
	 * @param location -
	 *            The local URI(http|ssh|etc://) of the branch root.
	 */
	public RemoteBranch(final URI location) {
		super();
		this.location = new BranchLocation(location);
	}
	
	public RemoteBranch(BranchLocation branchLocation) {
		super();
		this.location = branchLocation;
	}

	public boolean isLocal() {
		return false;
	}
	
	public String getNick() {
		// nick command don't work on remote branches
		return null;
	}
	
	public URI getLocation() {
		return location.getURI();
	}

	public IProject getProject() {
		// no project in a remote branch, right?
		return null;
	}

	public File getFile() {
		return null;
	}

	public IPath getPath() {
		// we handle all remote branches by they URI
		return null;
	}
	
	@Override
	public BranchLocation getBranchLocation() {
		return location;
	}
}