/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.internal.core.model.local;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IFolder;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalFile;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalFolder;

/**
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 * 
 */
public class BzrLocalFolder extends BzrLocalResource implements IBzrLocalFolder {

	/**
	 * @param folder
	 * @param branch
	 */
	public BzrLocalFolder(IFolder folder, IBzrBranch branch) {
		super(folder, branch);
	}

	public BzrLocalFolder(IContainer folder, IBzrBranch branch) {
		super(folder, branch);
	}

	public IContainer getIContainer() {
		return (IContainer) super.getIResource();
	}

	public boolean isFolder() {
		return true;
	}

	public IBzrLocalFile[] getFiles() throws CoreException {
		List<IBzrLocalFile> list = new ArrayList<IBzrLocalFile>();
		List<IResource> resources = Arrays.asList(getIContainer().members());
		for (IResource resource : resources) {
			if (!(resource instanceof IFile)) {
				list.add(new BzrLocalFile(resource, getBranch()));
			}
		}
		IBzrLocalFile[] result = new IBzrLocalFile[list.size()];
		return list.toArray(result);
	}

	public IBzrLocalFolder[] getSubFolders() throws CoreException {
		List<IBzrLocalFolder> list = new ArrayList<IBzrLocalFolder>();
		List<IResource> resources = Arrays.asList(getIContainer().members());
		for (IResource resource : resources) {
			if (resource instanceof IFolder) {
				list.add(new BzrLocalFolder((IFolder) resource, getBranch()));
			}
		}
		IBzrLocalFolder[] result = new IBzrLocalFolder[list.size()];
		return list.toArray(result);
	}

}
