/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.team.core.RepositoryProvider;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.AddCommand;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;

/**
 * @author Guillermo Gonzalez
 * 
 * TODO: Test me
 */

public class AddAction extends WorkbenchAction {

	/**
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 * 
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		run(new IRunnableWithProgress() {
			
			public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
				try {
					IProject[] projects = getSelectedProjects();
					if (projects.length == 1) {
						IProject project = projects[0];
						BazaarTeamProvider provider = (BazaarTeamProvider) RepositoryProvider.getProvider(project, EclipseBazaarCore.getProviderID());
						AddCommand op = new AddCommand(provider.getBzrWorkspaceRoot(), Arrays.asList(projects));
						op.run(EclipseBazaarCore.subProgressMonitorFor(monitor));
					} else {
						// associate the resources with their respective
						// RepositoryProvider
						Map<BazaarTeamProvider, List<IResource>> map = getProviderMapping(getSelectedResources());
						Set<BazaarTeamProvider> keySet = map.keySet();
						monitor.beginTask("", keySet.size() * 1000); //$NON-NLS-1$
						monitor.setTaskName(CoreTexts.AddCommand_adding); //$NON-NLS-1$
						for (BazaarTeamProvider provider : keySet) {
							List<IResource> resources = map.get(provider);
							AddCommand op = new AddCommand(provider.getBzrWorkspaceRoot(), resources);
							op.run(EclipseBazaarCore.subProgressMonitorFor(monitor));
						}
					}
				} catch (CoreException e) {
					// FIXME: exception handling
					EclipseBazaarUI.log(e.getMessage(), e);
					throw new InvocationTargetException(e);
				} finally {
					monitor.done();
				}
			}
		}, false /* no cancelable */, PROGRESS_DIALOG);
	}

	@Override
	protected boolean isEnabledForManagedResources() {
		if (getSelectedProjects().length == 1) {
			return true;
		}
		return false;
	}

}
