/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.progress.UIJob;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalFile;
import org.vcs.bazaar.eclipse.core.utils.BzrJobStatus;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.annotaions.ShowAnnotationOperation;

/**
 * @author Guillermo Gonzalez 
 */
public class AnnotateAction extends WorkbenchAction {

	public void execute(IAction action) throws BazaarException {
		Shell shell = getParentShell();

		IResource resource = getSelectedResources()[0]; // XXX: get only the
														// first element in the
														// selection
		if (resource instanceof IFile) {
			final IBzrLocalFile file = BzrWorkspaceRoot.getBzrFileFor(resource);
			final IWorkbenchPart activePart =AnnotateAction.this.getActivePage().getActivePart();
			Job job = new Job("Getting annotations") {
				@Override
				public IStatus run(IProgressMonitor monitor) {
					try {
						new ShowAnnotationOperation(activePart, file).run(monitor);
					} catch (InvocationTargetException e) {
						EclipseBazaarUI.log(e.getMessage(), e);
						return UIJob.errorStatus(e);
					} catch (InterruptedException e) {
						EclipseBazaarUI.log(e.getMessage(), e);
						return UIJob.errorStatus(e);
					} finally {
						monitor.done();
					}
					return BzrJobStatus.OK_STATUS;
				}
			};
			job.setUser(true);
			job.setPriority(Job.DECORATE);
			job.schedule();
		} else {
			// this should not be possible, only files can be "annotated"
			MessageDialog.openInformation(shell, "Bazaar Eclipse Annotate " + resource.getLocation().toString(), CoreTexts.Command_not_implemented);
		}
	}
	
	protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	protected boolean isEnabledForAddedResources() {
		return false;
	}
	
}
