/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Collection;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.commands.BindCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.repository.BranchFactory;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog.LocationDialogInfo;

/**
 * @author Guillermo Gonzalez
 *
 */
public class BindAction extends WorkbenchAction {

	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		// popup a input dialog to get the remote location
		IProject[] projects = getEnclosingProjectsForSelectedResources();
		final IProject project = projects[0];
		final LocationDialogInfo dialogInfo = new LocationDialogInfo();
		final IBzrBranch remoteLocation = getRemoteLocation(project, dialogInfo);
		if (remoteLocation != null) {
			run(new WorkspaceModifyOperation() {
				public void execute(IProgressMonitor monitor) throws InvocationTargetException {
					try {
						monitor.beginTask(CoreTexts.bind(CoreTexts.BindCommand_taskName, 
								new Object[]{project.getName(), remoteLocation.getBranchLocation().toString()}), 1000);
						BindCommand cmd = new BindCommand(project, remoteLocation);
						cmd.run(monitor);
					} catch (BazaarException e) {
						handle(e);
						throw new InvocationTargetException(e);
					} finally {
						monitor.done();
					}
				}
			}, false /* no cancelable */, PROGRESS_DIALOG);
		}
	}

	private IBzrBranch getRemoteLocation(IProject project, LocationDialogInfo dialogInfo) throws BazaarException {
		Collection<IBzrBranch> locations = getAllBranchLocations(project);
		LocationInputDialog dialog = LocationInputDialog.remoteBindLocationDialog(getShell(), locations, dialogInfo);
		dialog.setBlockOnOpen(true);
		if (dialog.open() == LocationInputDialog.OK) {
			return BranchFactory.getInstance().findOrCreateFor(dialogInfo.getLocation());
		}
		return null;
	}

	@Override
	protected boolean isEnabledByType(IResource resource) {
		if(resource.getType() == IResource.PROJECT) {
			BzrWorkspaceRoot root = BzrWorkspaceRoot.getBzrWorkspaceRootFor((IProject)resource);
			return !root.getBranch().isBound();
		}
		return false;
	}
	
	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return false;
	}
}
