/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.text.MessageFormat;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.team.core.TeamException;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.decorator.BazaarLightweightDecorator;

/**
 * @author Guillermo Gonzalez 
 * 
 */
public class DisconnectAction extends WorkspaceAction {

	public DisconnectAction() {
	}

	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		IProject[] projects = getSelectedProjects();
		if (projects.length > 0) {
			boolean ok = MessageDialog.openQuestion(getShell(), UITexts.DisconnectConfirmDialog_title, // $NON-NLS
			MessageFormat.format(UITexts.DisconnectConfirmDialog_body, new Object[]{projects[0].getName()})); // $NON-NLS
			if (ok) {
				try {
					BazaarTeamProvider.unmap(projects[0]);
					BazaarLightweightDecorator.refresh();
				} catch (CoreException e) {
					EclipseBazaarUI.log(e.getMessage(), e);
					throw BazaarException.wrapException(e);
				}
			}
		}
	}
	
	@Override
	protected boolean isEnabled() throws TeamException {
		IResource[] resources = getSelectedResources();

		if (resources.length == 0) {
			// don't enable if there no selection
			return false;
		}
		if (!isEnabledForMultipleResources() && resources.length != 1) {
			return false;
		}
		if (!isEnabledForMultipleEclosingProjects() && getEnclosingProjectsForSelectedResources().length != 1) {
			return false;
		}
		return true;
	}

	@Override
	protected boolean isEnabledByType(IResource resource) {
		if (resource.getType() == IResource.PROJECT)
			return true;
		return false;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return false;
	}

	@Override
	protected boolean isEnabledForMultipleResources() {
		return false;
	}

}
