/**
 * Copyright (C) 2009 Canonical Ltd
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Arrays;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.WorkspaceJob;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.action.IAction;
import org.eclipse.team.core.RepositoryProvider;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.IgnoreCommand;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @authors Javier Der Derian<javierder AT gmail DOT com><br>
 *          Guillermo Gonzalez <guillo.gonzo@gmail.com>
 * @BasedOn AddAction from BzrEclipse
 */
public class IgnoreAction extends WorkbenchAction {

    /**
     * The action has been activated. The argument of the method represents the
     * 'real' action sitting in the workbench UI.
     * 
     * @see IWorkbenchWindowActionDelegate#run
     */
    protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
        // Changed runner for Job
        final IResource[] resources = getSelectedResources();
        Job ignoreJob = new WorkspaceJob("adding to ignored...") {
            @Override
            public IStatus runInWorkspace(IProgressMonitor monitor) throws CoreException {
                BazaarTeamProvider provider = (BazaarTeamProvider) RepositoryProvider.getProvider(resources[0].getProject(), EclipseBazaarCore.getProviderID());
                IgnoreCommand op = new IgnoreCommand(provider.getBzrWorkspaceRoot(), Arrays.asList(resources));
                op.run(EclipseBazaarCore.subProgressMonitorFor(monitor));
                return Status.OK_STATUS;
            }
        };
        if (resources.length == 1) {
            ignoreJob.setRule(null);
            ignoreJob.setPriority(Job.LONG);
            ignoreJob.setUser(true);
            ignoreJob.schedule();
        }
    }

    @Override
    protected boolean isEnabledForManagedResources() {
        return false;
    }

    @Override
    protected boolean isEnabledForUnmanagedResources() {
        return true;
    }
    
    @Override
    protected boolean isEnabledForAddedResources() {
        return false;
    }

}
