/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.team.core.TeamException;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.InitCommand;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.decorator.BazaarLightweightDecorator;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class InitAction extends WorkbenchAction {

	private IPath bzrPath;
	private IProject project;

	public InitAction(IPath bzrPath, IProject project, Shell shell) {
		this.bzrPath = bzrPath;
		this.project = project;
		getShell().setParent(shell);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.vcs.bazaar.eclipse.ui.actions.BzrAction#execute(org.eclipse.jface.action.IAction)
	 */
	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		run(new WorkspaceModifyOperation() {
			public void execute(IProgressMonitor monitor) throws InvocationTargetException {
				try {
					monitor.beginTask("", 1000); //$NON-NLS-1$
					monitor.setTaskName(CoreTexts.InitCommand_taskName); //$NON-NLS-1$
					InitCommand op = new InitCommand(bzrPath, project);
					op.run(monitor);
				} catch (BazaarException e) {
					// FIXME: exception handling
					EclipseBazaarUI.log(e.getMessage(), e);
					throw new InvocationTargetException(e);
				} finally {
					monitor.done();
				}
			}
		}, false /* no cancelable */, PROGRESS_DIALOG);
		BazaarLightweightDecorator.refresh();
	}

	
	@Override
	protected boolean isEnabled() throws TeamException {
		if(!EclipseBazaarCore.getDefault().isClientAvailable()) {
			return false;
		}
		return !BazaarTeamProvider.isShared(project);
	}
}
