/**
 * LICENSE + COPYRIGHT 
 */
package org.vcs.bazaar.eclipse.ui.actions;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.action.IAction;
import org.eclipse.team.ui.TeamUI;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.ui.progress.UIJob;
import org.vcs.bazaar.eclipse.core.utils.BzrJobStatus;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.views.BazaarView;

/**
 * @author Guillermo Gonzalez 
 * TODO: Test (split into Operation and Action?)
 */
public class LogAction extends WorkbenchAction {

	/**
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 * 
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	public void execute(IAction action) {
		// XXX: get only the first element in the selection
		UIJob job = createJob();
		job.setUser(true);
		job.setPriority(UIJob.BUILD);
		job.schedule();
	}
	
	private UIJob createJob() {
		return new UIJob(this.getShell().getDisplay(), "Fetching revision history") {
			@Override
			public IStatus runInUIThread(IProgressMonitor monitor) {
				monitor.beginTask("fetching...", 100);
				final IResource resource = getSelectedResources()[0];
				try {
					if(resource.getType() == IResource.FILE) {
						monitor.subTask("fetching resource revisions");
						monitor.worked(20);
						TeamUI.getHistoryView().showHistoryFor(resource);
			 		} else {
			 			monitor.subTask("fetching project revisions");
			 			monitor.worked(20);
						final IWorkbenchPage activePage = EclipseBazaarUI.getDefault().getWorkbench().getActiveWorkbenchWindow().getActivePage();
						// Show View
						final IViewPart viewPart = activePage.showView(EclipseBazaarUI.getLogViewId());
						final BazaarView logView = (BazaarView) viewPart;
						// Send out put to the view
						logView.setInput(resource); 
			 		}
					return BzrJobStatus.OK_STATUS;
				} catch (Exception e) {
					EclipseBazaarUI.log(e.getMessage(), e);
					return UIJob.errorStatus(e);
				} finally {
					monitor.done();
				}
			}
		};
	}

	@Override
	protected boolean isEnabledForMultipleResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return false;
	}
	
	@Override
	protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForAddedResources() {
		return false;
	}
	
	@Override
	protected boolean isEnabledByType(IResource resource) {
		return resource.getType() == IResource.FILE || resource.getType() == IResource.PROJECT || resource.getType() == IResource.FOLDER;
	}
}
