/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Collection;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.commands.MergeCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.repository.BranchFactory;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.dialogs.MergeDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.MergeDialog.MergeDialogInfo;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class MergeAction extends WorkbenchAction {

	@Override
	protected void execute(IAction anAction) throws BazaarException, InvocationTargetException, InterruptedException {
		// popup a input dialog to get the remote location
		final IProject[] projects = getEnclosingProjectsForSelectedResources();
		final MergeDialogInfo dialogInfo = new MergeDialogInfo();
		final IBzrBranch remoteLocation = getRemoteLocation(projects[0], dialogInfo);
		if (remoteLocation != null) {
			run(new WorkspaceModifyOperation() {
				public void execute(IProgressMonitor monitor) throws InvocationTargetException {
					try {
						monitor.beginTask("", 1000); //$NON-NLS-1$
						monitor.setTaskName(CoreTexts.MergeCommand_taskName); //FIXME //$NON-NLS-1$
						// only enabled for one project at a time
						MergeCommand cmd = new MergeCommand(projects, remoteLocation.getBranchLocation(), dialogInfo.getOptions().toArray(new Option[0]));						
						cmd.run(monitor);
					} catch (BazaarException e) {
						EclipseBazaarUI.log(e.getMessage(), e);
						throw new InvocationTargetException(e, e.getMessage());
					} finally {
						monitor.done();
					}
				}
			}, false /* no cancelable */, PROGRESS_DIALOG);
		}
	}

	private IBzrBranch getRemoteLocation(IProject project, MergeDialogInfo dialogInfo) throws BazaarException {
		Collection<IBzrBranch> locations = getAllBranchLocations(project);
		MergeDialog dialog = new MergeDialog(getShell(), locations, dialogInfo);
		dialog.setBlockOnOpen(true);
		if (dialog.open() == MergeDialog.OK) {
			return BranchFactory.getInstance().findOrCreateFor(dialogInfo.getLocation());
		}
		return null;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}

}
