/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.commands.PullCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalBranch;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.core.repository.BranchFactory;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog.LocationDialogInfo;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class PullAction extends WorkbenchAction {

	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		// popup a input dialog to get the remote location
		final IProject[] projects = getEnclosingProjectsForSelectedResources();
		final LocationDialogInfo dialogInfo = getRemoteLocation(projects[0]);
		if (dialogInfo != null && dialogInfo.getLocation() != null && !"".equals(dialogInfo.getLocation().trim())) {
			final IBzrBranch location = BranchFactory.getInstance().findOrCreateFor(dialogInfo.getLocation());
			run(new WorkspaceModifyOperation() {
				public void execute(IProgressMonitor monitor) throws InvocationTargetException {
					try {
						monitor.beginTask("", 1000); //$NON-NLS-1$
						monitor.setTaskName(CoreTexts.bind(CoreTexts.PullCommand_taskName, location.getBranchLocation().toString())); //$NON-NLS-1$
						// only enabled for one project at a time
						PullCommand cmd = new PullCommand(projects[0], location);
						cmd.setRemember(dialogInfo.isRemember());
						cmd.run(monitor);
					} catch (BazaarException e) {
						// FIXME: exception handling
						EclipseBazaarUI.log(e.getMessage(), e);
						throw new InvocationTargetException(e, e.getMessage());
					} finally {
						monitor.done();
					}
				}
			}, false /* no cancelable */, PROGRESS_DIALOG);
		}
	}

	private LocationDialogInfo getRemoteLocation(IProject project) throws BazaarException {
		final LocationDialogInfo dialogInfo = new LocationDialogInfo();
		List<IBzrBranch> locations = new ArrayList<IBzrBranch>();
		BazaarTeamProvider provider = BzrWorkspaceRoot.getProviderFor(project);
		if(provider.getBranch().isLocal()) {
			locations.addAll(((IBzrLocalBranch)provider.getBranch()).getPullLocations());
			Collections.sort(locations);
		}
		LocationInputDialog dialog = LocationInputDialog.remotePullLocationDialog(getShell(), locations, dialogInfo);
		dialog.setBlockOnOpen(true);
		if (dialog.open() == LocationInputDialog.OK) {
			return dialogInfo;
		}
		return null;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return false;
	}

}
