/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.eclipse.core.resources.IProject;
import org.eclipse.jface.action.IAction;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalBranch;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.core.repository.BranchFactory;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog.LocationDialogInfo;
import org.vcs.bazaar.eclipse.ui.operations.PushOperation;

/**
 * @author Guillermo Gonzalez
 * 
 */
public class PushAction extends WorkbenchAction {


	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		// popup a input dialog to get the remote location
		IProject[] projects = getEnclosingProjectsForSelectedResources();
		final IProject project = projects[0];
		execute(project);
	}
	
	protected void execute(final IProject aProject) throws InvocationTargetException, InterruptedException {
		final LocationDialogInfo dialogInfo = getRemoteLocation(aProject);
		if (dialogInfo != null && dialogInfo.getLocation() != null && !"".equals(dialogInfo.getLocation().trim())) {
			IBzrBranch branch = BranchFactory.getInstance().findOrCreateFor(dialogInfo.getLocation().trim());
			new PushOperation(getTargetPart(), aProject, branch.getBranchLocation(), dialogInfo.isRemember(), dialogInfo.isUseExistingDir()).run();
		}
	}

	private LocationDialogInfo getRemoteLocation(IProject aProject) {
		final LocationDialogInfo dialogInfo = new LocationDialogInfo();
		try {
			List<IBzrBranch> locations = new ArrayList<IBzrBranch>();
			BazaarTeamProvider provider = BzrWorkspaceRoot.getProviderFor(aProject);
			if (provider.getBranch().isLocal()) {
				locations.addAll(((IBzrLocalBranch) provider.getBranch()).getPushLocations());
				Collections.sort(locations);
			}
			LocationInputDialog dialog = LocationInputDialog.remotePushLocationDialog(getShell(), locations, dialogInfo);
			dialog.setBlockOnOpen(true);
			if (dialog.open() == LocationInputDialog.OK) {
				return dialogInfo;
			}

		} catch (Exception ex) {
			// this is an unexpected exception (ok, no so unexpected ;), but is for sure a bug)
			handle(ex);
		}
		return null;
	}

	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return false;
	}

}
