/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.ResolveCommand;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 * 
 */
public class ResolveAction extends WorkbenchAction {

	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		run(new WorkspaceModifyOperation() {
		
			@Override
			protected void execute(IProgressMonitor monitor) throws CoreException, InvocationTargetException, InterruptedException {
				try {
					Map<IProject, List<IResource>> map = getProjectMapping(getSelectedResources());
					Set<IProject> keySet = map.keySet();
					monitor.beginTask("Resolving conflicts", keySet.size() * 1000); //$NON-NLS-1$
					for (IProject project : keySet) {
						List<IResource> resources = map.get(project);
						ResolveCommand cmd = new ResolveCommand(resources);
						cmd.run(EclipseBazaarCore.subProgressMonitorFor(monitor));
						monitor.worked(resources.size()*10);
					}
				} catch (BazaarException e) {
					EclipseBazaarUI.log(e);
					throw new InvocationTargetException(e);
				} finally {
					monitor.done();
				}
			}
		}, false /* no cancelable */, PROGRESS_DIALOG);
	}

	@Override
	protected boolean isEnabledForManagedResources() {
		return true;
	}
	
	@Override
	protected boolean isEnabledForAddedResources() {
		return false;
	}
	
	@Override
	protected boolean isEnabledForMultipleResources() {
		return true;
	}
	
	@Override
	protected boolean isEnabledForUnmanagedResources() {
		return false;
	}
	
	@Override
	protected boolean isEnabledForConflictedResources() {
		return true;
	}
	
	@Override
	protected boolean isEnabledForUnmodifiedResources() {
		return false;
	}
	
	@Override
	protected boolean isEnabledForModifiedResources() {
		return false;
	}
	
}
