/**
 * org.vcs.bazaar.eclipse (c) Vectrace Sep 12, 2006
 * Created by zingo
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.commands.RevertCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.actions.CommitAction.CommitableResources;
import org.vcs.bazaar.eclipse.ui.dialogs.RevertDialog;

/**
 * @author Guillermo Gonzalez <guillo DOT gonzo AT gmail DOT com>
 */
public class RevertAction extends WorkbenchAction {

	/**
	 * <p>
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 * </p>
	 * 
	 * @throws BazaarException
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		IProject[] projects = getEnclosingProjectsForSelectedResources(); 
		CommitableResources commiteableResources = null;
		List<IBzrResourceStatus> selectedResources = CommitAction.getCommitableResources(new NullProgressMonitor(), getSelectedResources());
		if(projects.length > 1) {
			commiteableResources = CommitAction.createCommitableResources(new NullProgressMonitor(), projects);
		} else {
			commiteableResources = CommitAction.createCommitableResources(new NullProgressMonitor(), new IResource[]{projects[0]});
		}
		RevertDialog dialog = new RevertDialog(this.getShell(), commiteableResources.getAllStatuses(), selectedResources);
		dialog.setWholeBranchEnabled(true);
		if(dialog.open() != RevertDialog.OK || (dialog.getSelection().size() == 0 && !dialog.isWholeBranch())) {
			return;
		}
		final List<IBzrLocalResource> resourcesToRevert = new ArrayList<IBzrLocalResource>();
		if(dialog.isWholeBranch()) {
			// ignore the selection the revert applies to the whole branch
			resourcesToRevert.addAll(Arrays.asList(BzrWorkspaceRoot.getBzrResourcesFor(projects)));
		} else {
			for (IBzrResourceStatus bzrResourceStatus : dialog.getSelection()) {
				resourcesToRevert.add(bzrResourceStatus.getResource());
			}	
		}
		final RevertCommand cmd = new RevertCommand(resourcesToRevert, dialog.isWholeBranch(), dialog.getOptions());
		run(new WorkspaceModifyOperation() {
			public void execute(IProgressMonitor monitor) throws InvocationTargetException {
				try {
					cmd.run(monitor);
				} catch (BazaarException e) {
					// FIXME: exception handling
					throw new InvocationTargetException(e);
				} finally {
					monitor.done();
				}
			}
		}, false /* no cancelable */, PROGRESS_DIALOG);
	}
	
	protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForUnmodifiedResources() {
		if(getSelectedProjects().length > 1) {
			return true;
		} else if(getSelectedProjects().length == 1) {
			return true;
		}
		return false;
	}
	
	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return isSameBranchInEnclosingProjects();
	}
}
