/**
* Copyright (C) 2009 Canonical Ltd
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Collection;

import org.eclipse.core.resources.IProject;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.dialogs.SendDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.SendDialog.SendDialogInfo;
import org.vcs.bazaar.eclipse.ui.operations.SendOperation;

/**
 * @author Javier Der Derian<javierder AT gmail DOT com>
 * @BasedOn RevertAction from BzrEclipse
 */
public class SendAction extends WorkbenchAction {

	/**
	 * <p>
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 * </p>
	 * 
	 * @throws BazaarException
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		IProject[] projects = getEnclosingProjectsForSelectedResources(); 

		Collection<IBzrBranch> locations = getAllBranchLocations(projects[0]);
		
		SendDialog dialog = new SendDialog(this.getShell(), locations, new SendDialogInfo());
		
		if(dialog.open() != SendDialog.OK) {
			return;
		}

		final IBzrLocalResource[] resourcesToSend = BzrWorkspaceRoot.getBzrResourcesFor(projects);

		
		new SendOperation(getTargetPart(), resourcesToSend[0], dialog.getOptions(), new BranchLocation(dialog.getValue())).run();
		
	}
	
	protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	@Override
	protected boolean isEnabledForUnmodifiedResources() {
		if(getSelectedProjects().length == 1) {
			return true;
		}
		return false;
	}
	
	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return false;
	}
}
