/**
 * org.vcs.bazaar.eclipse (c) Vectrace Jan 31, 2006
 * Created by zingo
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.List;
import java.util.Map;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.progress.IProgressService;
import org.vcs.bazaar.client.IBazaarLogMessage;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.commands.StatusCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;

/**
 * @author zingo 
 * TODO: test and split into Operation and Action
 */
public class StatusAction extends WorkspaceAction {

	/**
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 * 
	 * @throws InterruptedException
	 * @throws InvocationTargetException
	 * 
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	public void execute(IAction action) throws InvocationTargetException, InterruptedException {
		IProgressService service = PlatformUI.getWorkbench().getProgressService();
		// XXX: a test for run a command and monitor with ProgressService, this
		// action is executed in foreground
		// TODO: this must be moved to StatusOperation which is subclass of
		// TeamOperation
		service.run(false, false, new IRunnableWithProgress() {
			public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
				try {
					monitor.beginTask("Getting Synchronize status from local branch", getSelectedResources().length);
					Map<IProject, List<IResource>> map = getProjectMapping(getSelectedResources());
					for (IProject project : map.keySet()) {
						StatusCommand cmd = new StatusCommand(project, BzrWorkspaceRoot.getBzrResourcesFor(map.get(project).toArray(new IResource[0])));
						cmd.run(monitor);
						// TODO: we should show the status in some kind of
						// synchronize view or dialog 
						for (IBzrResourceStatus status : cmd.getStatus()) {
							if(!status.isIgnored() && !status.isUnchanged() && status.getResource().getIResource().getType() != IResource.PROJECT)
								EclipseBazaarUI.getDefault().getConsole().logMessage(status.getStatus().toString());
						}
						if(cmd.getPendingMerges().size() > 0) {
							EclipseBazaarUI.getDefault().getConsole().logMessage("pending merges:\n");
						}
						showPendingMerges(cmd.getPendingMerges(), new StringBuilder());
					}
				} catch (Exception e) {
					throw new InvocationTargetException(e);
				} finally {
					monitor.done();
				}
			}
		});
	}

	protected void showPendingMerges(List<IBazaarLogMessage> pendingMerges, StringBuilder tab) {
		tab.append("    ");
		for (IBazaarLogMessage log : pendingMerges) {
			StringBuilder sb = new StringBuilder(100);
			sb.append(tab.toString()).append(log.getAuthor()).append(" ").append(log.getTimeStamp()).append(" ").append(log.getMessage());
			EclipseBazaarUI.getDefault().getConsole().logMessage(sb.toString());
			if(log.getMerged() != null) {
				showPendingMerges(log.getMerged(), new StringBuilder(tab.toString()));
			}
		}
	}
	
}
