/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;
import java.util.Collection;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.commands.SwitchCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.repository.BranchFactory;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog;
import org.vcs.bazaar.eclipse.ui.dialogs.LocationInputDialog.LocationDialogInfo;

/**
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class SwitchAction extends WorkbenchAction {
	
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		IProject[] projects = getEnclosingProjectsForSelectedResources();
		final IProject project = projects[0];
		final LocationDialogInfo dialogInfo = new LocationDialogInfo();
		// popup a input dialog to get the remote location
		String remoteLocation = getRemoteLocation(project, dialogInfo);
		if (remoteLocation != null) {
			final IBzrBranch location = BranchFactory.getInstance().findOrCreateFor(remoteLocation);
			run(new IRunnableWithProgress() {
				public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
					try {
						monitor.beginTask(CoreTexts.bind(CoreTexts.SwitchCommand_taskName, 
								location.getBranchLocation().toString()), 2000);
						SwitchCommand cmd = new SwitchCommand(project, location);
						cmd.run(monitor);
					} catch (BazaarException e) {
						throw new InvocationTargetException(e);
					} finally {
						monitor.done();
					}
				}
			}, "Cannot switch a branch, only a checkout.", PROGRESS_DIALOG);
		}
	}

	private String getRemoteLocation(IProject project, LocationDialogInfo dialogInfo) throws BazaarException {
		Collection<IBzrBranch> locations = getAllBranchLocations(project);
		LocationInputDialog dialog = LocationInputDialog.switchLocationDialog(getShell(), locations, dialogInfo);
		dialog.setBlockOnOpen(true);
		if (dialog.open() == LocationInputDialog.OK) {
			return dialogInfo.getLocation();
		}
		return null;
	}

	@Override
	protected boolean isEnabledByType(IResource resource) {
		if(resource.getType() == IResource.PROJECT) {
			BzrWorkspaceRoot root = BzrWorkspaceRoot.getBzrWorkspaceRootFor((IProject)resource);
			return !root.getBranch().isBound();
		}
		return false;
	}
	
	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return false;
	}

}
