/**
 * LICENCSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.client.IBazaarLogMessage;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.commands.UnCommitCommand;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.dialogs.UncommitDialog;

/**
 * @author Guillermo Gonzalez
 * 
 * TODO: needs revision & test (maybe split into Operation and Action)
 */
public class UnCommitAction extends WorkbenchAction {

	/**
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 * 
	 * @throws BazaarException
	 * 
	 * @see IWorkbenchWindowActionDelegate#run
	 */

	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		final IProject project = getEnclosingProjectsForSelectedResources()[0];
		IBazaarLogMessage logMessage;
		try {
			logMessage = EclipseBazaarCore.getDefault().getLogCacheManager().getLastLog(project);
		} catch (CoreException e) {
			throw BazaarException.wrapException(e);
		}
		boolean dialogStatus = new UncommitDialog(getShell(), logMessage).open()==Dialog.OK;
		if (dialogStatus) {
			IBazaarLogMessage lastLogMessage;
			try {
				lastLogMessage = EclipseBazaarCore.getDefault().getLogCacheManager().getLastLog(project);
			} catch (CoreException e) {
				throw BazaarException.wrapException(e);
			}
			if(!lastLogMessage.getRevision().equals(logMessage.getRevision())) {
				MessageDialog.openError(getShell(), "Error while trying to uncommit", "The tip of the branch changed, please execute uncommit again to see the latest revision details");
			} else {
				run(new WorkspaceModifyOperation() {
					public void execute(IProgressMonitor monitor) throws InvocationTargetException {
						try {
							monitor.beginTask("", 1000); //$NON-NLS-1$
							monitor.setTaskName(CoreTexts.UnCommitCommand_unCommiting);
							UnCommitCommand cmd = new UnCommitCommand(new IProject[]{project});
							cmd.run(monitor);
						} catch (BazaarException e) {
							EclipseBazaarUI.log(e.getMessage(), e);
							throw new InvocationTargetException(e);
						} finally {
							monitor.done();
						}
					}
				}, false /* no cancelable */, PROGRESS_DIALOG);
			}
		}
	}
	
	protected boolean isEnabledForUnmanagedResources() {
		return false;
	}

	protected boolean isEnabledForAddedResources() {
		return false;
	}

}
