/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
import org.vcs.bazaar.eclipse.core.commands.UpdateCommand;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * 
 * @author Guillermo Gonzalez
 *
 */
public class UpdateAction extends WorkbenchAction {

	/**
	 * <p>
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 * </p>
	 * 
	 * @throws BazaarException
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	@Override
	protected void execute(IAction action) throws BazaarException, InvocationTargetException, InterruptedException {
		IProject project = getSelectedProjects()[0];
		final UpdateCommand cmd = new UpdateCommand(project);
		run(new WorkspaceModifyOperation() {
			public void execute(IProgressMonitor monitor) throws InvocationTargetException {
				try {
					cmd.run(monitor);
				} catch (BazaarException e) {
					handle(e);
				} finally {
					monitor.done();
				}
			}
		}, false /* no cancelable */, PROGRESS_DIALOG);
		MessageDialog.openInformation(getShell(), "Update finished", cmd.getOutputMessage());
	}
	
	@Override
	protected boolean isEnabledByType(IResource resource) {
		return resource.getType() == IResource.PROJECT;
	}
	
	@Override
	protected boolean isEnabledForMultipleEclosingProjects() {
		return false;
	}

}
