/*******************************************************************************
 * Copyright (c) 2004, 2006 Subclipse project and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Subclipse project committers - initial API and implementation
 * Modified by: 
 * 	   Guillermo Gonzalez
 ******************************************************************************/
package org.vcs.bazaar.eclipse.ui.annotaions;

import java.util.LinkedList;
import java.util.List;

import org.vcs.bazaar.client.IBazaarAnnotation;

public class AnnotateBlocks {
	private List<AnnotateBlock> blocks = new LinkedList<AnnotateBlock>();
	
	public AnnotateBlocks(IBazaarAnnotation annotation) {
		for (int i = 0; i < annotation.getNumberOfLines();i++) {
			AnnotateBlock block = new AnnotateBlock(
					annotation.getRevision(i),
					annotation.getAuthor(i),
					annotation.getDate(i),
					i,i);
			add(block);
		}
	}

	/**
	 * Add an annotate block merging this block with the
	 * previous block if it is part of the same change.
	 * @param aBlock
	 */
	private void add(AnnotateBlock aBlock) {
		int size = blocks.size();
		if (size == 0) {
			blocks.add(aBlock);
		} else {
			AnnotateBlock lastBlock = (AnnotateBlock) blocks.get(size - 1);
			if (lastBlock.getRevision().equals(aBlock.getRevision())) {
				lastBlock.setEndLine(aBlock.getStartLine());
			} else {
				blocks.add(aBlock);
			}
		}
	}	

	public List<AnnotateBlock> getAnnotateBlocks() {
		return blocks;
	}	
	
}
