/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.compare;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.compare.CompareConfiguration;
import org.eclipse.compare.CompareEditorInput;
import org.eclipse.compare.ResourceNode;
import org.eclipse.compare.structuremergeviewer.Differencer;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;

/**
 * Read only compare editor input
 * 
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class BazaarCompareEditorInput extends CompareEditorInput {
	
	private static final Differencer DIFFERENCER = new Differencer();
	private ResourceNode left;
	private ResourceNode right;
	
	/**
	 * This constructor use a default configuration with both side read-only
	 * @param resource
	 * @param left
	 * @param right
	 */
	public BazaarCompareEditorInput(IResource resource, ResourceNode left, ResourceNode right) {
		this(new CompareConfiguration(), resource, left, right);
		getCompareConfiguration().setLeftEditable(false);
		getCompareConfiguration().setRightEditable(false);
	}
	
	public BazaarCompareEditorInput(CompareConfiguration configuration,
			IResource resource, ResourceNode left, ResourceNode right) {
		super(configuration);
		this.left = left;
		this.right = right;
		setTitle(resource.getName());
		configuration.setLeftLabel(left.getName());
		configuration.setRightLabel(right.getName());
	}

	@Override
	protected Object prepareInput(IProgressMonitor monitor)
			throws InvocationTargetException, InterruptedException {
		return DIFFERENCER.findDifferences(false, monitor, null, null, left, right);
	}
}
