/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.compare;

import java.io.InputStream;

import org.eclipse.core.runtime.CoreException;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.core.resources.IStorageBazaarRevision;

public class BazaarRevisionNode extends BazaarResourceNode {
	
	private final IStorageBazaarRevision rev;

	public BazaarRevisionNode(IBzrLocalResource resource, BazaarRevision revision) {
		super(resource);
		this.rev = new IStorageBazaarRevision(resource.getIResource(), revision);
	}

	public BazaarRevisionNode(IStorageBazaarRevision rev) {
		super(rev.getResource());
		this.rev = rev;
	}

	@Override
	public String getName() {
		return rev.getName();
	}

	@Override
	public InputStream getContents() throws CoreException {
		return rev.getContents();
	}
	
	@Override
	protected InputStream createStream() throws CoreException {
		return getContents();
	}
	
	@Override
	public boolean isEditable() {
		return false;
	}
	
	@Override
	public String getCharset() {
		String charset = null;
		try {
			charset = rev.getResourceCharset();
		} catch (CoreException e) {
		} finally {
			if(charset == null) {
				charset = super.getCharset();
			}
		}
		return charset;
	}
}