/*******************************************************************************
 * Copyright (c) 2003, 2006 Subclipse project and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Subclipse project committers - initial API and implementation
 * Modified by: 
 *	   Guillermo Gonzalez 
 ******************************************************************************/
package org.vcs.bazaar.eclipse.ui.console;

import org.eclipse.jface.action.Action;
import org.eclipse.team.ui.TeamImages;
import org.eclipse.ui.IActionBars;
import org.eclipse.ui.console.IConsole;
import org.eclipse.ui.console.IConsoleConstants;
import org.eclipse.ui.console.IConsolePageParticipant;
import org.eclipse.ui.part.IPageBookViewPage;
import org.vcs.bazaar.eclipse.ui.UITexts;

/**
 * Console helper that allows contributing actions to the console view when the
 * Bazaar console is visible. Added to the console via an extension point from
 * org.eclipse.ui.console.
 * 
 */
public class BzrConsolePageParticipant implements IConsolePageParticipant {

	private ConsoleRemoveAction consoleRemoveAction;

	public void init(IPageBookViewPage page, IConsole console) {
		this.consoleRemoveAction = new ConsoleRemoveAction();
		IActionBars bars = page.getSite().getActionBars();
		bars.getToolBarManager().appendToGroup(IConsoleConstants.LAUNCH_GROUP, consoleRemoveAction);
	}

	public void dispose() {
		this.consoleRemoveAction = null;
	}

	public void activated() {
	}

	public void deactivated() {
	}

	@SuppressWarnings("unchecked")
	public Object getAdapter(Class adapter) {
		return null;
	}

	/**
	 * Action to remove the console. This can be re-added via the console view
	 * drop down menu.
	 */
	private final static class ConsoleRemoveAction extends Action {

		public ConsoleRemoveAction() {
			this.setText(UITexts.BazaarConsole_removeAction_label);
			setToolTipText(UITexts.BazaarConsole_removeAction_tooltip);
			setImageDescriptor(TeamImages.getImageDescriptor("elcl16/participant_rem.gif")); //$NON-NLS-1$
			setDisabledImageDescriptor(TeamImages.getImageDescriptor("dlcl16/participant_rem.gif")); //$NON-NLS-1$
		}

		public void run() {
			BzrOutputConsoleFactory.closeConsole();
		}
	}
}