/*******************************************************************************
 * Copyright (c) 2003, 2006 Subclipse project and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Subclipse project committers - initial API and implementation
 * Modified by: 
 *	   Guillermo Gonzalez 
 ******************************************************************************/
package org.vcs.bazaar.eclipse.ui.console;

import org.eclipse.jface.preference.BooleanFieldEditor;
import org.eclipse.jface.preference.ColorFieldEditor;
import org.eclipse.jface.preference.FieldEditorPreferencePage;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.preference.IntegerFieldEditor;
import org.eclipse.jface.util.PropertyChangeEvent;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.preferences.BazaarPreferenceConstants;

public class ConsolePreferencesPage extends FieldEditorPreferencePage implements IWorkbenchPreferencePage {

	public ConsolePreferencesPage() {
		super(GRID);
		setPreferenceStore(EclipseBazaarUI.getDefault().getPreferenceStore());
	}

	private ColorFieldEditor commandColorEditor;
	private ColorFieldEditor messageColorEditor;
	private ColorFieldEditor errorColorEditor;
	private BooleanFieldEditor showOnDebug;
	private BooleanFieldEditor showOnMessage;
	private BooleanFieldEditor showOnError;
	private BooleanFieldEditor restrictOutput;
	private IntegerFieldEditor highWaterMark;

	protected void createFieldEditors() {
		Composite composite = getFieldEditorParent();
		IPreferenceStore store = getPreferenceStore();

		restrictOutput = new BooleanFieldEditor(BazaarPreferenceConstants.PREF_CONSOLE_LIMIT_OUTPUT, UITexts.BazaarConsole_preferences_limitOutput,
				composite);
		addField(restrictOutput);

		highWaterMark = new IntegerFieldEditor(BazaarPreferenceConstants.PREF_CONSOLE_HIGH_WATER_MARK, UITexts.BazaarConsole_preferences_highWaterMark,
				composite);
		highWaterMark.setValidRange(1000, Integer.MAX_VALUE - 1);
		addField(highWaterMark);
		highWaterMark.setEnabled(store.getBoolean(BazaarPreferenceConstants.PREF_CONSOLE_LIMIT_OUTPUT), composite);

		showOnMessage = new BooleanFieldEditor(BazaarPreferenceConstants.PREF_CONSOLE_SHOW_ON_MESSAGE, UITexts.BazaarConsole_preferences_showOnMessage,
				composite);
		addField(showOnMessage);

		showOnError = new BooleanFieldEditor(BazaarPreferenceConstants.PREF_CONSOLE_SHOW_ON_ERROR, UITexts.BazaarConsole_preferences_showOnError,
				composite);
		addField(showOnError);

		showOnDebug = new BooleanFieldEditor(BazaarPreferenceConstants.PREF_CONSOLE_SHOW_ON_DEBUG, UITexts.BazaarConsole_preferences_showOnDebug,
				composite);
		addField(showOnDebug);

		createLabel(composite, UITexts.BazaarConsole_preferences_consoleColorSettings); //$NON-NLS-1$
		commandColorEditor = createColorFieldEditor(BazaarPreferenceConstants.PREF_CONSOLE_COMMAND_COLOR, UITexts.BazaarConsole_preferences_commandColor,
				composite); //$NON-NLS-1$
		addField(commandColorEditor);

		messageColorEditor = createColorFieldEditor(BazaarPreferenceConstants.PREF_CONSOLE_MESSAGE_COLOR, UITexts.BazaarConsole_preferences_messageColor,
				composite); //$NON-NLS-1$
		addField(messageColorEditor);

		errorColorEditor = createColorFieldEditor(BazaarPreferenceConstants.PREF_CONSOLE_ERROR_COLOR, UITexts.BazaarConsole_preferences_errorColor,
				composite); //$NON-NLS-1$
		addField(errorColorEditor);
	}

	public void propertyChange(PropertyChangeEvent event) {
		super.propertyChange(event);
		highWaterMark.setEnabled(restrictOutput.getBooleanValue(), getFieldEditorParent());
	}

	/**
	 * Utility method that creates a label instance and sets the default layout
	 * data.
	 * 
	 * @param parent
	 *            the parent for the new label
	 * @param text
	 *            the text for the new label
	 * @return the new label
	 */
	private Label createLabel(Composite parent, String text) {
		Label label = new Label(parent, SWT.LEFT);
		label.setText(text);
		GridData data = new GridData();
		data.horizontalSpan = 2;
		data.horizontalAlignment = GridData.FILL;
		label.setLayoutData(data);
		return label;
	}

	/**
	 * Creates a new color field editor.
	 */
	private ColorFieldEditor createColorFieldEditor(String preferenceName, String label, Composite parent) {
		ColorFieldEditor editor = new ColorFieldEditor(preferenceName, label, parent);
		editor.setPage(this);
		editor.setPreferenceStore(getPreferenceStore());
		return editor;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
	 */
	public void init(IWorkbench workbench) {
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.jface.preference.IPreferencePage#performOk()
	 */
	public boolean performOk() {
		EclipseBazaarUI.getDefault().savePluginPreferences();
		return super.performOk();
	}
}
