package org.vcs.bazaar.eclipse.ui.decorator;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.team.ui.ISharedImages;
import org.eclipse.team.ui.TeamImages;
import org.vcs.bazaar.client.BazaarStatusKind;
import org.vcs.bazaar.client.IBazaarStatus;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;

/**
 * Set of images that are used for decorating resources are maintained here.
 * This acts as a image registry and hence there is a single copy of the image
 * files floating around the project.
 * 
 */
public class DecoratorImages extends DecoratorResources {
	
	public static final ImageDescriptor addedDescriptor = EclipseBazaarUI.getImageDescriptor("images/added.png");
	public static final ImageDescriptor deletedStillTrackedDescriptor = EclipseBazaarUI.getImageDescriptor("images/deleted_still_tracked.png");
	public static final ImageDescriptor ignoredDescriptor = EclipseBazaarUI.getImageDescriptor("images/ignored.png");
	public static final ImageDescriptor modifiedDescriptor = TeamImages.getImageDescriptor(ISharedImages.IMG_DIRTY_OVR);
	public static final ImageDescriptor notTrackedDescriptor = EclipseBazaarUI.getImageDescriptor("images/not_tracked.png");
	public static final ImageDescriptor removedDescriptor = EclipseBazaarUI.getImageDescriptor("images/removed.png");
	public static final ImageDescriptor managedDescriptor = TeamImages.getImageDescriptor(ISharedImages.IMG_CHECKEDIN_OVR);
	public static final ImageDescriptor conflictDescriptor = TeamImages.getImageDescriptor(ISharedImages.IMG_CONFLICT_OVR);
	public static final ImageDescriptor renameDescriptor = TeamImages.getImageDescriptor(ISharedImages.IMG_DIRTY_OVR);

	private static final Map<BazaarStatusKind, ImageDescriptor> imgDescriptorMap;
	static {
		imgDescriptorMap = new HashMap<BazaarStatusKind, ImageDescriptor>(9);
		imgDescriptorMap.put(BazaarStatusKind.CREATED, addedDescriptor);
//		imgDescriptorMap.put(BazaarStatusKind.DELETED, deletedStillTrackedDescriptor);
//		imgDescriptorMap.put(null, ignoredPrefix);
		imgDescriptorMap.put(BazaarStatusKind.MODIFIED, modifiedDescriptor);
		imgDescriptorMap.put(BazaarStatusKind.UNKNOWN, notTrackedDescriptor);
		imgDescriptorMap.put(BazaarStatusKind.DELETED, removedDescriptor);
		imgDescriptorMap.put(BazaarStatusKind.UNCHANGED, managedDescriptor);
		imgDescriptorMap.put(BazaarStatusKind.HAS_CONFLICTS, conflictDescriptor);
		imgDescriptorMap.put(BazaarStatusKind.RENAMED, renameDescriptor);	
	}

	/**
	 * Get the image descriptor depending on the key
	 * 
	 * @return image descriptor
	 * 
	 */
	public static final ImageDescriptor getImageDescriptor(IBazaarStatus status) {
		BazaarStatusKind kind = getStatusFlagKind(status);
		if(kind != null)
			return imgDescriptorMap.get(kind);
		return null;
	}

	public static final ImageDescriptor getImageDescriptor(IBzrResourceStatus status) throws BazaarException {
		return getImageDescriptor(status.getStatus());
	}

}
