/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.dialogs;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.graphics.Image;
import org.vcs.bazaar.client.BazaarStatusKind;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.ui.UITexts;

/**
 * 
 * @author Guillermo Gonzalez <guillo DOT gonzo AT gmail DOT com>
 *
 */
public final class CommitResourceLabelProvider extends LabelProvider implements ITableLabelProvider {
	
	private static final Map<BazaarStatusKind, String> FILE_STATUS_DESCRIPTION = new HashMap<BazaarStatusKind, String>(6);
	static {
		FILE_STATUS_DESCRIPTION.put(BazaarStatusKind.CREATED, UITexts.CommitDialog_statusAdded);
		FILE_STATUS_DESCRIPTION.put(BazaarStatusKind.MODIFIED, UITexts.CommitDialog_statusModified);
		FILE_STATUS_DESCRIPTION.put(BazaarStatusKind.DELETED, UITexts.CommitDialog_statusRemoved);
		FILE_STATUS_DESCRIPTION.put(BazaarStatusKind.RENAMED, UITexts.CommitDialog_statusRenamed);
		FILE_STATUS_DESCRIPTION.put(BazaarStatusKind.UNKNOWN, UITexts.CommitDialog_statusUntracked);
	}
	
	public Image getColumnImage(Object element, int columnIndex) {
		// No images.
		return null;
	}

	public String getColumnText(Object element, int columnIndex) {
		if (!(element instanceof IBzrResourceStatus)) {
			return "Type Error"; //$NON-NLS-1$
		}
		IBzrResourceStatus resource = (IBzrResourceStatus) element;

		if (columnIndex == 0) {
			return resource.getStatus().getPath();
		} else if (columnIndex == 1) {
			if (resource.contains(BazaarStatusKind.RENAMED)) {
				return FILE_STATUS_DESCRIPTION.get(BazaarStatusKind.RENAMED);
			}
			if (resource.contains(BazaarStatusKind.UNKNOWN)) {
				return FILE_STATUS_DESCRIPTION.get(BazaarStatusKind.UNKNOWN);
			}
			if (resource.contains(BazaarStatusKind.CREATED)) {
				return FILE_STATUS_DESCRIPTION.get(BazaarStatusKind.CREATED);
			}
			if (resource.contains(BazaarStatusKind.MODIFIED)) {
				return FILE_STATUS_DESCRIPTION.get(BazaarStatusKind.MODIFIED);
			}
			if (resource.contains(BazaarStatusKind.DELETED)) {
				return FILE_STATUS_DESCRIPTION.get(BazaarStatusKind.DELETED);
			}
		}
		return UITexts.CommitDialog_columnError;
	}
}