/**
 * 
 */
package org.vcs.bazaar.eclipse.ui.dialogs;

import java.util.List;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.dialogs.TrayDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.progress.UIJob;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.IBazaarLogMessage;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.history.HistoryTree;

public class ShowLogDialog extends TrayDialog {
	private HistoryTree logTree;
	private IBzrBranch branch;
	private RefreshLog refreshLogJob;
	private BazaarRevision selectedRevision;

	public ShowLogDialog(Shell shell, IBzrBranch branch) {
		super(shell);
		setShellStyle(SWT.RESIZE | SWT.MODELESS | SWT.CLOSE | SWT.BORDER | SWT.TITLE);
		this.branch = branch;
	}
	
	@Override
	protected Control createDialogArea(Composite parent) {
		Composite composite  = (Composite)super.createDialogArea(parent);
		logTree = new HistoryTree(composite);
		refresh();
		return composite;
	}
	

	/**
	 * Return the initial size of the dialog
	 */
	@Override
	protected Point getInitialSize() {
		return new Point(700, 400);
	}
	
	protected void showLog(List<IBazaarLogMessage> logs) {
		logTree.populate(logs);
	}

	public BazaarRevision getSelectedRevision() {
		return selectedRevision;
	}
	
	@Override
	protected void okPressed() {
		selectedRevision = logTree.getSelection().getRevision();
		super.okPressed();
	}
	
	public void refresh() {
		if (this.branch != null) {
			if (refreshLogJob == null) {
				refreshLogJob = new RefreshLog();
			}
			if (refreshLogJob.getState() != Job.NONE) {
				refreshLogJob.cancel();
			}
			refreshLogJob.setResource(this.branch);
			refreshLogJob.schedule();
		}
	}
	
	private class RefreshLog extends Job {
		private IBzrBranch branch;
		
		public RefreshLog() {
			super("Fetching Bazaar revisions..."); //$NON-NLS-1$
			this.setUser(true);
			this.setPriority(UIJob.LONG);
		}
		
		public void setResource(IBzrBranch branch) {
			this.branch = branch;
		}

		public IStatus run(IProgressMonitor monitor) {
			IStatus status = Status.OK_STATUS;
			if (this.branch != null) {
				monitor.beginTask("", 1000);
				IProgressMonitor subMonitor = EclipseBazaarCore.subProgressMonitorFor(monitor);
				try {					
					monitor.worked(100);
					final List<IBazaarLogMessage> logMessages = EclipseBazaarCore.getDefault().getLogCacheManager().getLogs(this.branch);
					monitor.worked(400);
					if(!monitor.isCanceled()) {
						ShowLogDialog.this.getShell().getDisplay().asyncExec(new Runnable() {
							public void run() {
								if(!ShowLogDialog.this.logTree.isDisposed()) {
									ShowLogDialog.this.showLog(logMessages);
								}
							}
						});
					}
					monitor.worked(400);
				} catch (CoreException e) {
					EclipseBazaarUI.log(e);
					status = e.getStatus();
				} catch (Exception e) {
					EclipseBazaarUI.log(BazaarException.wrapException(e));
					return UIJob.errorStatus(e);
				} finally {
					monitor.done();
				}
			}
			return status;
		}
	}
	
	@Override
	public boolean close() {
		if (refreshLogJob.getState() != Job.NONE) {
			refreshLogJob.cancel();
		}
		return super.close();
	}
	
}