package org.vcs.bazaar.eclipse.ui.dialogs;

import java.text.SimpleDateFormat;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.layout.GridDataFactory;
import org.eclipse.jface.layout.GridLayoutFactory;
import org.eclipse.jface.layout.LayoutConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.vcs.bazaar.client.IBazaarLogMessage;

/**
 * <p>
 * A confirmation dialog for the uncommit action.
 * </p>
 * <p>
 * It shows revno, commiter, date and the message in the custom area
 * </p>
 * TODO: move string literals to uitexts.properties
 */
public class UncommitDialog extends MessageDialog {

	private IBazaarLogMessage log;

	public UncommitDialog(Shell parentShell, IBazaarLogMessage log) {
		super(parentShell, getTitle(log), null, getMessage(log), MessageDialog.QUESTION, new String[] { IDialogConstants.YES_LABEL, IDialogConstants.NO_LABEL }, 0); // yes is the
		this.log = log;
	}

	static String getMessage(IBazaarLogMessage log) {
		return "The specified revision(s) will be removed. " + System.getProperty("line.separator") + "Are you sure?";
	}

	static String getTitle(IBazaarLogMessage log) {
		return "Confirm uncommit";
	}

	@Override
	protected Control createCustomArea(Composite parent) {
		Point defaultMargins = LayoutConstants.getMargins();
		Composite contents = new Composite(parent, SWT.RESIZE);
		contents.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, false));
		
		new Label(contents, SWT.LEFT).setText("Revno:");
		new Label(contents, SWT.LEFT).setText(log.getRevision().getValue());
		new Label(contents, SWT.LEFT).setText("Commiter:");
		new Label(contents, SWT.LEFT).setText(log.getCommiter().trim());
		new Label(contents, SWT.LEFT).setText("Date:");
		new Label(contents, SWT.LEFT).setText(new SimpleDateFormat("yyyy-MM-dd").format(log.getDate()).trim());
		Group messageGroup = new Group(contents, SWT.NONE);
		messageGroup.setText("Message");
        GridLayoutFactory.fillDefaults().numColumns(1).margins(defaultMargins.x, defaultMargins.y).applyTo(messageGroup);
        messageGroup.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 2, 1));
		Label label = new Label(messageGroup, SWT.LEFT | SWT.WRAP);
		label.setText(log.getMessage().trim());
		GridDataFactory.fillDefaults().grab(true, false).align(SWT.FILL, SWT.FILL).applyTo(label);

		Dialog.applyDialogFont(parent);		
		
        GridLayoutFactory.fillDefaults().numColumns(2).margins(defaultMargins.x, defaultMargins.y).applyTo(contents);
		return contents;
	}
	
}
