/**
 * 
 */
package org.vcs.bazaar.eclipse.ui.dialogs;

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.TrayDialog;
import org.eclipse.jface.resource.JFaceColors;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.StyleRange;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.MouseMoveListener;
import org.eclipse.swt.events.TraverseEvent;
import org.eclipse.swt.events.TraverseListener;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Cursor;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.browser.IWebBrowser;
import org.eclipse.ui.browser.IWorkbenchBrowserSupport;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.UITexts;

/**
 * Dialog requesting the user to verify that bzr-eclipse dependencies are
 * fulfilled.
 * <p>
 * Usually displayed after bzr-eclipse has either been upgraded or newly
 * installed.
 * 
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 */
public class UpdateInfoDialog extends TrayDialog {

	private IWebBrowser browser;
	private StyledText text;
	private int offset;
	private int linkLength;
    private Cursor handCursor;
    private boolean mouseDown = false;
    private boolean dragEvent = false;
    final String link;
    final String message;
	
	public UpdateInfoDialog(Shell shell) {
		super(shell);
		IWorkbenchBrowserSupport browserSupport = EclipseBazaarUI.getActivePage().getWorkbenchWindow().getWorkbench().getBrowserSupport();
		try{
			
			if(browserSupport.isInternalWebBrowserAvailable()) {
				browser = browserSupport.createBrowser(null);				
			} else {
				browser = browserSupport.getExternalBrowser();	
			}
		}catch(PartInitException e){}
		setHelpAvailable(false);
		link = UITexts.bind("bzr_eclipse_home_link");
		message = UITexts.bind("update_message");
	}


	@Override
	protected Control createButtonBar(Composite parent) {
		Control control = super.createButtonBar(parent);
		((GridData)control.getLayoutData()).heightHint = 60;
		return control;
	}
	
	@Override
	protected Control createDialogArea(Composite parent) {
		Color background = JFaceColors.getBannerBackground(parent.getDisplay());
		Color foreground = JFaceColors.getBannerForeground(parent.getDisplay());
		handCursor = new Cursor(parent.getDisplay(), SWT.CURSOR_HAND);
		Composite container = (Composite)super.createDialogArea(parent);
		GridLayout layout = new GridLayout();
		
		container.setLayoutData(new GridData(GridData.FILL_BOTH));
		container.setBackground(background);
		container.setForeground(foreground);
        layout.numColumns = 1;
        layout.marginWidth = 0;
        layout.marginHeight = 0;
        layout.verticalSpacing = 0;
        layout.horizontalSpacing = 0;
        container.setLayout(layout);
        GridData data = new GridData();
        data.horizontalAlignment = GridData.FILL;
        data.grabExcessHorizontalSpace = true;
        data.grabExcessVerticalSpace = true;
        container.setLayoutData(data);

        // adds an imaage to the dialog
        // we need a bigger image than the used in the dialogs
//        BzrWizardPage.getTitleImage();
//        Image bzrEclipseImage = BzrWizardPage.getTitleImage().createImage();
//        Label imageLabel = new Label(container, SWT.NONE);
//		imageLabel.setBackground(background);
//		imageLabel.setForeground(foreground);

//		data = new GridData();
//		data.horizontalAlignment = GridData.FILL;
//		data.verticalAlignment = GridData.BEGINNING;
//		data.grabExcessHorizontalSpace = false;
//		imageLabel.setLayoutData(data);
//		imageLabel.setImage(bzrEclipseImage);
     
	    

		text = new StyledText(container, SWT.MULTI | SWT.READ_ONLY | SWT.WRAP);
		text.setEditable(false);
		text.setCursor(null);
		linkLength = link.length();
		text.setText(message + link);
		offset = text.getText().indexOf("http://");
		Color fg = JFaceColors.getHyperlinkText(text.getShell().getDisplay());
        StyleRange r = new StyleRange(offset, linkLength, fg, null);
        text.setStyleRange(r);
        addListeners(text);
        text.setBackground(background);
        text.setForeground(foreground);
        
        data = new GridData();
		data.horizontalAlignment = GridData.FILL;
		data.verticalAlignment = GridData.FILL;
		data.grabExcessHorizontalSpace = true;
		data.grabExcessVerticalSpace = true;
		data.minimumHeight = 100;
		text.setLayoutData(data);
		return container;
	}
	
	protected void createButtonsForButtonBar(Composite parent) {
		// create the OK button
		createButton(parent, IDialogConstants.OK_ID, IDialogConstants.OK_LABEL, true);
	}

    /**
     * Adds listeners to the given styled text
     */
    protected void addListeners(StyledText styledText) {
        styledText.addMouseListener(new MouseAdapter() {
            public void mouseDown(MouseEvent e) {
                if (e.button != 1) {
                    return;
                }
                mouseDown = true;
            }

            public void mouseUp(MouseEvent e) {
                mouseDown = false;
                StyledText text = (StyledText) e.widget;
                int offset = text.getCaretOffset();
                if (dragEvent) {
                    // don't activate a link during a drag/mouse up operation
                    dragEvent = false;
                    
                    if (UpdateInfoDialog.this.offset + linkLength >= offset && offset >= UpdateInfoDialog.this.offset) {
                        text.setCursor(handCursor);
                    }
                } else if (UpdateInfoDialog.this.offset + linkLength >= offset && offset >= UpdateInfoDialog.this.offset) {
                	try {
						browser.openURL(new URL(link));
					} catch (PartInitException e1) {
						e1.printStackTrace();
					} catch (MalformedURLException e1) {
						e1.printStackTrace();
					}
                }
            }
        });

        styledText.addMouseMoveListener(new MouseMoveListener() {
            public void mouseMove(MouseEvent e) {
                // Do not change cursor on drag events
                if (mouseDown) {
                    if (!dragEvent) {
                        StyledText text = (StyledText) e.widget;
                        text.setCursor(null);
                    }
                    dragEvent = true;
                    return;
                }
                StyledText text = (StyledText) e.widget;
                int offset = -1;
                try {
                    offset = text.getOffsetAtLocation(new Point(e.x, e.y));
                } catch (IllegalArgumentException ex) {
                    // leave value as -1
                }
                if (offset == -1) {
					text.setCursor(null);
				} else if (UpdateInfoDialog.this.offset + linkLength >= offset && offset >= UpdateInfoDialog.this.offset) {
					text.setCursor(handCursor);
				} else {
					text.setCursor(null);
				}
            }
        });

        styledText.addTraverseListener(new TraverseListener() {
            public void keyTraversed(TraverseEvent e) {
                switch (e.detail) {
                case SWT.TRAVERSE_ESCAPE:
                    e.doit = true;
                    break;
                default:
                    break;
                }
            }
        });
    }

}
