/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.history;

import java.util.List;

import org.eclipse.jface.layout.TreeColumnLayout;
import org.eclipse.jface.viewers.ColumnWeightData;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerSorter;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeColumn;
import org.vcs.bazaar.client.IBazaarLogMessage;
import org.vcs.bazaar.eclipse.core.history.BazaarFileRevision;
import org.vcs.bazaar.eclipse.ui.history.HistoryTree.Column;

/**
 * @author Guillermo Gonzalez
 *
 */
public class HistoryTreeHelper {
	
	protected static class LogLabelProvider extends LabelProvider implements ITableLabelProvider {

		public String getColumnText(Object obj, int index) {
			String ret = "";

			if (!(obj instanceof BazaarFileRevision)) {
				return "Type Error";
			}

			BazaarFileRevision bazaarFileRevision = (BazaarFileRevision) obj;
			IBazaarLogMessage logMessage = bazaarFileRevision.getIBazaarLogMessage();

			switch (index) {
			case 0:
				ret = logMessage.getRevision().getValue();
				break;
// case 1:
// ret = logMessage.getTag();
// break;
			case 1:
				ret = logMessage.getCommiter();
				break;
			case 2:
				ret = logMessage.getTimeStamp();
				break;
			case 3:
				ret = logMessage.getBranchNick();
				break;
			case 4:
				ret = logMessage.getMessage();
				break;
//			case 5:
//				StringBuffer sb = new StringBuffer();
//				for (IBazaarStatus fileStatus : logMessage.getFiles()) {
//					sb.append(fileStatus.getPath()).append(" ");
//				}
//				ret = sb.toString();
//				break;
			default:
				ret = null;
				break;
			}
			return ret;
		}

		public Image getColumnImage(Object obj, int index) {
			return null;
		}
	}
	
	protected static class RevisionSorter extends ViewerSorter {

		@Override
		public int compare(Viewer viewer, Object e1, Object e2) {

			if (!(e1 instanceof BazaarFileRevision) || !(e1 instanceof BazaarFileRevision)) {
				return super.compare(viewer, e1, e2);
			}
			BazaarFileRevision revision1 = (BazaarFileRevision) e1;
			BazaarFileRevision revision2 = (BazaarFileRevision) e2;
			return revision2.compareRevisionTo(revision1);
		}
	}
	
	public static final TreeViewer createTreeViewer(Composite composite) {
		HistoryTree tree = new HistoryTree(composite, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL);
		return createTreeViewer(tree);
	}
	
	public static final TreeViewer createTreeViewer(HistoryTree tree) {
		return createTreeViewer(tree.getTree());
	}
	
	public static final TreeViewer createTreeViewer(Tree tree) {
		TreeViewer viewer = new TreeViewer(tree);
		viewer.setLabelProvider(new LogLabelProvider());
		viewer.setSorter(new RevisionSorter());
		return viewer;
	}
	
	/* package */ static Tree configureTree(Composite parent, Tree logTree, Column...columns) {
		logTree.setLinesVisible(true);
		logTree.setHeaderVisible(true);
		
		TreeColumnLayout layout = new TreeColumnLayout();
		parent.setLayout(layout);

		TreeColumn column = null; 
		// changesetTableColumn.setResizable(true);
		for (Column col : columns) {
			if(col.equals(Column.REVNO)) {
				column = new TreeColumn(logTree, SWT.LEFT);
				column.setText("Revision");
				layout.setColumnData(column, new ColumnWeightData(5, true));
				column.setData(Column.REVNO);
			} else if(col.equals(Column.TAGS)) {
				// column = new TreeColumn(logTree, SWT.LEFT);
				// column.setText("Tags");
				// layout.addColumnData(new ColumnWeightData(10, true));
				//layout.setColumnData(column, new ColumnWeightData(10, true));
				// column.setData(Column.TAGS);
			} else if(col.equals(Column.COMMITTER)) {
				column = new TreeColumn(logTree, SWT.LEFT);
				column.setText("Commiter");
				layout.setColumnData(column, new ColumnWeightData(13, true));
				column.setData(Column.COMMITTER);
			} else if(col.equals(Column.TIMESTAMP)) {
				column = new TreeColumn(logTree, SWT.LEFT);
				column.setText("TimeStamp");
				column.setData(Column.TIMESTAMP);		
				layout.setColumnData(column, new ColumnWeightData(13, true));
			} else if(col.equals(Column.BRANCH_NICK)) {
				column = new TreeColumn(logTree, SWT.LEFT);
				column.setText("Branch nick");
				layout.setColumnData(column, new ColumnWeightData(7, true));
				column.setData(Column.BRANCH_NICK);
			} else if(col.equals(Column.MESSAGE)) {
				column = new TreeColumn(logTree, SWT.LEFT);
				column.setText("Message");
				layout.setColumnData(column, new ColumnWeightData(30, true));
				column.setData(Column.MESSAGE);
			} else if(col.equals(Column.FILES)) {
				//column = new TreeColumn(logTree, SWT.LEFT);
				//column.setText("Files");
				//layout.setColumnData(column, new ColumnWeightData(25, true));
				//column.setData(Column.FILES);
			}
		}
		return logTree;
	}

	
	public static void populateTree(HistoryTree logTree, List<IBazaarLogMessage> logMessages) {
		populateTree(logTree, logMessages, false);
	}
	
	public static void populateTree(HistoryTree logTree, List<IBazaarLogMessage> logMessages, boolean onlyMainline) {
		if(logTree == null)
			return;
		logTree.setOnlyShownMainline(onlyMainline);
		logTree.populate(logMessages);
	}
	


}
