/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.operations;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.operation.IRunnableContext;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.vcs.bazaar.eclipse.core.commands.BranchCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProviderType;
import org.vcs.bazaar.eclipse.core.repository.BranchLocationManager;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;

/**
 * @author Guillermo Gonzalez
 * 
 * TODO: Test me
 */
public class BranchAsProjectOperation extends BzrOperation {
	private final IBzrBranch fromLocation;
	private final IProject project;
	private final String revno;
	private final IProjectDescription projectDescription;

	/**
	 * 
	 * @param fromLocation The parent of the project
	 * @param project
	 * @param revno
	 */
	public BranchAsProjectOperation(IRunnableContext context, IBzrBranch fromLocation, IProject project, String revno) {
		this(context, fromLocation, project, null, revno);
	}

	public BranchAsProjectOperation(IRunnableContext context, IBzrBranch fromLocation, IProjectDescription description, String revno) {
		this(context, fromLocation, null, description, revno);
	}
	
	public BranchAsProjectOperation(IRunnableContext context, IBzrBranch fromLocation, IProject project, IProjectDescription description, String revno) {
		super(context);
		this.fromLocation = fromLocation;
		if(project == null) {
			this.project = ResourcesPlugin.getWorkspace().getRoot().getProject(description.getName());
		} else { 
			this.project = project;
		}
		this.projectDescription = description;
		this.revno = revno!=null&&"".equals(revno.trim())?null:revno;
	}

	/**
	 * The action has been activated. The argument of the method represents the
	 * 'real' action sitting in the workbench UI.
	 * 
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
		try {
			runCommand(monitor);
			if(getProjectDescription() == null) {
				getProject().create(monitor);
			} else {
				getProject().create(getProjectDescription(), monitor);
			}
			getProject().open(monitor);
			// Register the project with Team. This will bring all the files
			// that we cloned into the project.
			BazaarTeamProviderType.registerProject(getProject());
			if (getFromLocation() != null && !BranchLocationManager.getInstance().getAllBranches().contains(getFromLocation())) {
			   BranchLocationManager.getInstance().addRepoLocation(getFromLocation());
			}
		} catch (BazaarException e) {
			EclipseBazaarUI.log(e);
			throw new InvocationTargetException(e, e.getMessage());
		} catch (CoreException e) {
			EclipseBazaarUI.log(e);
			throw new InvocationTargetException(e, e.getMessage());
		} finally {
			monitor.done();
		}
	}

	/**
	 * @param monitor
	 * @throws BazaarException
	 */
	protected void runCommand(IProgressMonitor monitor) throws BazaarException {
		BranchCommand op = null;
		if(getProjectDescription() == null)
			op = new BranchCommand(getFromLocation(), getProject().getWorkspace().getRoot().getLocation().append(getProject().getName()).toFile().toURI(), getRevno());
		else 
			op = new BranchCommand(getFromLocation(), getProjectDescription().getLocationURI(), getRevno());
		op.run(monitor);
	}
	
	@Override
	protected boolean canRunAsJob() {
		return true;
	}

	/**
	 * @return the projectDescription
	 */
	protected IProjectDescription getProjectDescription() {
		return projectDescription;
	}

	/**
	 * @return the fromLocation
	 */
	protected IBzrBranch getFromLocation() {
		return fromLocation;
	}

	/**
	 * @return the project
	 */
	protected IProject getProject() {
		return project;
	}

	/**
	 * @return the revno
	 */
	protected String getRevno() {
		return revno;
	}

}
