/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.operations;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.operation.IRunnableContext;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.commandline.syntax.ICheckoutOptions;
import org.vcs.bazaar.eclipse.core.commands.CheckoutCommand;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 * 
 */
public class CheckoutAsProjectOperation extends BranchAsProjectOperation {

	private Option[] options;

	/**
	 * 
	 * @param fromLocation The parent of the project
	 * @param description
	 * @param revno
	 */
	public CheckoutAsProjectOperation(IRunnableContext context, IBzrBranch fromLocation, IProjectDescription description, String revno, boolean lightweight) {
		this(context, fromLocation, null, description, revno, lightweight);
	}

	public CheckoutAsProjectOperation(IRunnableContext context, IBzrBranch fromLocation, IProject project, String revno, boolean lightweight) {
		this(context, fromLocation, project, null, revno, lightweight);
	}
	
	public CheckoutAsProjectOperation(IRunnableContext context, IBzrBranch fromLocation, IProject project, IProjectDescription description, String revno, boolean lightweight) {
		super(context, fromLocation, project, description, revno);
		List<Option> options = new ArrayList<Option>(0);
		if(lightweight) {
			options.add(ICheckoutOptions.LIGHTWEIGHT);
		}
		if(revno != null && !"".equals(revno.trim())) {
			options.add(ICheckoutOptions.REVISION.setArgument(BazaarRevision.getRevision(BazaarRevision.Prefix.REVNO, revno).toString()));
		}
		this.options = options.toArray(new Option[0]);
	}

	protected void runCommand(IProgressMonitor monitor) throws BazaarException {
		CheckoutCommand op = null;
		if(getProjectDescription() == null) {
			op = new CheckoutCommand(getFromLocation(), getProject().getWorkspace().getRoot().getLocation().append(getProject().getName()).toFile().toURI(), options);
		} else {
			op = new CheckoutCommand(getFromLocation(), getProjectDescription().getLocationURI(), options);
		}
		op.run(monitor);
	}
	
	@Override
	protected boolean canRunAsJob() {
		return true;
	}
	
}
