/**
 * 
 */
package org.vcs.bazaar.eclipse.ui.operations;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.compare.CompareEditorInput;
import org.eclipse.compare.CompareUI;
import org.eclipse.compare.ResourceNode;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.operation.IRunnableContext;
import org.eclipse.team.core.TeamException;
import org.eclipse.team.core.synchronize.SyncInfo;
import org.eclipse.team.ui.synchronize.SyncInfoCompareInput;
import org.eclipse.ui.IWorkbenchPage;
import org.vcs.bazaar.client.BazaarRevision;
import org.vcs.bazaar.eclipse.core.resources.IStorageBazaarRevision;
import org.vcs.bazaar.eclipse.core.subscriber.BazaarStatusSuscriber;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.compare.BazaarCompareEditorInput;
import org.vcs.bazaar.eclipse.ui.compare.BazaarResourceNode;
import org.vcs.bazaar.eclipse.ui.compare.BazaarRevisionNode;
import org.vcs.bazaar.eclipse.ui.compare.SaveableBazaarCompareEditorInput;

/**
 * This class don't implement it run method, it only provides static methods 
 * to open a compare editor or dialog
 * 
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class DiffOperation extends BzrOperation {

	protected DiffOperation(IRunnableContext context) {
		super(context);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.operation.IRunnableWithProgress#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public void run(IProgressMonitor monitor) throws InvocationTargetException,
			InterruptedException {
	}

	/**
	 * Open a SaveableCompareEditor showing the comparsion of local vs last revision contents
	 * @param file
	 * @throws TeamException
	 */
	public static void openSaveableEditor(IResource file) throws TeamException {
		openSaveableEditor(file, new IStorageBazaarRevision(file));
	}
	
	public static void openSaveableEditor(IResource file, IWorkbenchPage page) {
		openSaveableEditor(file, new IStorageBazaarRevision(file), page);
	}

	public static void openSaveableEditor(IResource file, BazaarRevision revision) throws TeamException {
		openSaveableEditor(file, new IStorageBazaarRevision(file, revision), EclipseBazaarUI.getActivePage());
	}

	public void openEditor(IResource file, BazaarRevision revision) {
		openEditor(null, new IStorageBazaarRevision(file, revision));
	}
	
	public static void openEditor(IStorageBazaarRevision left, IStorageBazaarRevision right) {
		openEditor(getNode(left), getNode(right));
	}

	/**
	 * Open a CompareDialog showing the comparsion of local vs last revision contents
	 * @param file
	 */
	public static void openDialog(IResource file) {
		openDialog(null, new IStorageBazaarRevision(file));
	}
	
	public static void openDialog(IStorageBazaarRevision left, IStorageBazaarRevision right) {
		openDialog(getNode(left), getNode(right));
	}
	
	/**
	 * This method assumes that the left node is the local (and newest) file
	 * @param left {@link ResourceNode}
	 * @param right {@link ResourceNode}
	 */
	public static void openEditor(ResourceNode left, ResourceNode right) {
		CompareEditorInput editorInput = getEditorInput(left, right, right.getResource());
		CompareUI.openCompareEditor(editorInput);
	}
	
	public static void openDialog(ResourceNode left, ResourceNode right) {
		IResource resource = right.getResource();
		CompareEditorInput editorInput = getEditorInput(left, right, resource);
		CompareUI.openCompareDialog(editorInput);
	}
	
	public static void openSaveableEditor(IResource left, IStorageBazaarRevision right, IWorkbenchPage page) {
		CompareEditorInput editorInput = getSaveableEditorInput(left, right, page);
		CompareUI.openCompareEditorOnPage(editorInput, page);
	}
	
	/**
	 * Open a CompareEditor using the syncInfo provided by {@link BazaarStatusSuscriber}
	 * @param left
	 * @param right
	 * @throws TeamException
	 */
    public static void openSaveableEditor(IResource left, IStorageBazaarRevision right) throws TeamException {
		BazaarStatusSuscriber subscriber = BazaarStatusSuscriber.getInstance();
		SyncInfo syncInfo;
		syncInfo = subscriber.getSyncInfo(left, null, right);
		SyncInfoCompareInput comparedialog = new SyncInfoCompareInput("diffelidiff", syncInfo);
		CompareUI.openCompareDialog(comparedialog);
	}
    
	/**
	 * @param left {@link ResourceNode}
	 * @param right {@link ResourceNode}
	 * @param resource {@link IResource}
	 * @return
	 */
	private static CompareEditorInput getEditorInput(ResourceNode left,
			ResourceNode right, IResource resource) {
		CompareEditorInput editorInput = new BazaarCompareEditorInput(resource,
				left != null ? left : new BazaarResourceNode(resource),
				right);
		return editorInput;
	}
	
	/**
	 * @param left {@link IResource}
	 * @param right {@link ResourceNode}
	 * @param page
	 * @return
	 */
	private static CompareEditorInput getSaveableEditorInput(IResource left, IStorageBazaarRevision right, IWorkbenchPage page) {
		CompareEditorInput editorInput = new SaveableBazaarCompareEditorInput(left,
				left != null ? new BazaarResourceNode(left) : getNode(right),
				left != null ? getNode(right) : new ResourceNode(left), page);
		return editorInput;
	}

	private static BazaarRevisionNode getNode(IStorageBazaarRevision rev) {
		  return rev == null ? null : new BazaarRevisionNode(rev);
	}	
	
}
