/**
 * 
 */
package org.vcs.bazaar.eclipse.ui.operations;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.ui.IWorkbenchPart;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.commands.PushCommand;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalBranch;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 *
 */
public class PushOperation extends BzrOperation {
	
	private IProject project;
	private BranchLocation location;
	private boolean remember;
	private boolean useExsitingDir;

	public PushOperation(IProject project, BranchLocation location, boolean remember, boolean useExsitingDir) {
		this(null, project, location, remember, useExsitingDir);
	}
	
	public PushOperation(IProject project) {
		this(null, project, getPushLocation(project), false, false);
	}
	
	private static BranchLocation getPushLocation(IProject project) {
		BazaarTeamProvider provider = BzrWorkspaceRoot.getProviderFor(project);
		if (provider.getBranch().isLocal()) {
			return ((IBzrLocalBranch) provider.getBranch()).getPushBranch().getBranchLocation();
		}
		return null;
	}

	public PushOperation(IWorkbenchPart part, IProject project, BranchLocation location, boolean remember, boolean useExsitingDir) {
		super(part);
		this.project = project;
		this.location = location;
		this.remember = remember;
		this.useExsitingDir = useExsitingDir;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.operation.IRunnableWithProgress#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
		try {
			monitor.beginTask(CoreTexts.bind(CoreTexts.PushCommand_taskName, location.toString()), 1000); 
			PushCommand cmd = new PushCommand(project, location);
			cmd.setRemember(remember);
			cmd.setUseExsitingDir(useExsitingDir);
			cmd.run(monitor);
		} catch (BazaarException e) {
			throw new InvocationTargetException(e);
		} finally {
			monitor.done();
		}
	}
	
	@Override
	protected String getJobName() {
		return "Pushing " + project.getName();
	}
	
	@Override
	protected boolean canRunAsJob() {
		return true;
	}

}
