/**
* Copyright (C) 2009 Canonical Ltd
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
package org.vcs.bazaar.eclipse.ui.operations;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.ui.IWorkbenchPart;
import org.vcs.bazaar.client.commandline.commands.options.Option;
import org.vcs.bazaar.client.core.BranchLocation;
import org.vcs.bazaar.eclipse.CoreTexts;
import org.vcs.bazaar.eclipse.core.commands.SendCommand;
import org.vcs.bazaar.eclipse.core.model.local.IBzrLocalResource;
import org.vcs.bazaar.eclipse.internal.core.BazaarException;

/**
 * @author Javier Der Derian <javierder at gmail dot com>
 * @BasedOn PushOperation from BzrEclipse
 */
public class SendOperation extends BzrOperation {
	
	private final IBzrLocalResource resource;
	private Option[] options;
	private BranchLocation branchLocation;

	public SendOperation(IWorkbenchPart part, IBzrLocalResource bzrResource, Option[] options, BranchLocation branchLocation) {
		super(part);
		this.resource = bzrResource;
		this.options = options;
		this.branchLocation = branchLocation;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.operation.IRunnableWithProgress#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
		try {
			monitor.beginTask(CoreTexts.bind(CoreTexts.SendCommand_send, branchLocation.toString()), 1000); 
			final SendCommand cmd = new SendCommand(resource, options, branchLocation);
			cmd.run(monitor);
		} catch (BazaarException e) {
			throw new InvocationTargetException(e);
		} finally {
			monitor.done();
		}
	}
	
	@Override
	protected String getJobName() {
		return "Sending " + resource.getName();
	}
	
	@Override
	protected boolean canRunAsJob() {
		return true;
	}

}
