/**
 * org.vcs.bazaar.eclipse (c) Vectrace Feb 3, 2006
 * Created by zingo
 */
package org.vcs.bazaar.eclipse.ui.team;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.Preferences;
import org.eclipse.jface.preference.PreferenceDialog;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.dialogs.PreferencesUtil;
import org.vcs.bazaar.client.BazaarPreference;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;

/**
 * @author zingo
 * 
 * This class is full of utilities methods, useful all over the place
 */
public class BazaarUtilities {



	/** ************************* bazaar command *********************** */

	/**
	 * Returns the executable for bzr. If it's not defined, false is returned
	 * 
	 * @return false if no bzr is defined. True if bzr executable is defined
	 */
	public static String getBzrExecutable() {
		final Preferences prefs = EclipseBazaarCore.getDefault().getPluginPreferences();
		return prefs.getString(BazaarPreference.EXECUTABLE.name());
	}
	
	/**
	 * This will get the bzr executable. If the bzr executable location has not be configured,
	 * it will return the default "bzr" or if one sets the parameter configureIfMissing to TRUE
	 * the it will open up the preference page to allow the user to specify the bzr executable 
	 * if it has not been configured.
	 * 
	 * @param configureIfMissing
	 * @return
	 */
	public static String getBzrExecutable(boolean configureIfMissing) {
		if (EclipseBazaarCore.getDefault().isClientAvailable()) {
			return getBzrExecutable();
		} else {
			if (configureIfMissing) {
				configureExecutable();
				return getBzrExecutable();
			} else {
				return "bzr";
			}
		}
	}
	
	/**
	 * This will open the preference dialog to allow the user to edit the location of the bzr executable 
	 */
	public static void configureExecutable() {		
		configureExecutable(EclipseBazaarUI.getStandardDisplay().getActiveShell());
	}
	
	/**
	 * This will open the preference dialog to allow the user to edit the location of the bzr executable 
	 */
	public static void configureExecutable(Shell shell) {		
		final String pageId = "org.vcs.bazaar.eclipse.ui.preferences.BazaarPreferencePage";			
		final String[] dsplIds = new String[]{pageId};
		final PreferenceDialog dlg = PreferencesUtil.createPreferenceDialogOn(shell, pageId, dsplIds, null);
		dlg.open();
	}

	/** ************************* Username *********************** */

	/**
	 * Returns the Username for bzr. If it's not defined, false is returned
	 * 
	 * @return false if no bzr is defined. True if bzr executable is defined
	 */
	public static String getBzrUsername() {
		final Preferences prefs = EclipseBazaarCore.getDefault().getPluginPreferences();
		return prefs.getString(BazaarPreference.BZR_EMAIL.name());
	}

	public static String getBzrUsername(boolean configureIfMissing) {
		final String uname = getBzrUsername();
		if (uname != null) {
			return uname;
		} else {
			if (configureIfMissing) {
				configureUsername();
				return getBzrUsername();
			} else {
				return System.getProperty("user.name");
			}
		}
	}
	/**This will open the preference dialog to allow the user to edit the user name of the bazaar branch*/
	public static void configureUsername() {
		final String pageId = "org.vcs.bazaar.eclipse.ui.preferences.BazaarPreferencePage";
		final String[] dsplIds = new String[]{pageId};
		final Display display = PlatformUI.getWorkbench().getDisplay(); 
		final PreferenceDialog dlg = PreferencesUtil.createPreferenceDialogOn(display.getActiveShell(), pageId, dsplIds, null);
		dlg.open();
	}

	/**
	 * Get the project for the selection (it uses the first element in the selection parameter)
	 * 
	 * @param selection
	 * @return
	 */
	public static IProject getProject(IStructuredSelection selection) {		
		final Object obj = selection.getFirstElement();
		if ((obj != null) && (obj instanceof IResource)) {
			return ((IResource) obj).getProject();
		}
		return null;
	}

}
