/**
 * 
 */
package org.vcs.bazaar.eclipse.ui.team;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.IExecutionListener;
import org.eclipse.core.commands.NotHandledException;
import org.eclipse.core.expressions.EvaluationContext;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IResourceChangeEvent;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.ui.commands.ICommandService;
import org.vcs.bazaar.eclipse.BzrWorkspaceRoot;
import org.vcs.bazaar.eclipse.core.listeners.AbstractResourceChangeListener;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.core.utils.ResourceUtil;

/**
 * A IExecutionListener implementation that hooks into RefreshCommands calls.
 * 
 * @author Guillermo Gonzaelz <guillo.gonzo@gmail.com>
 */
public final class RefreshExecutionListener extends AbstractResourceChangeListener implements IExecutionListener {
	private static final String REFRESH_ID = "org.eclipse.ui.file.refresh";
	
	public void addTo(ICommandService cmdService) {
		cmdService.getCommand(REFRESH_ID).addExecutionListener(this);
	}
	
	public void removeFrom(ICommandService cmdService) {
		if(cmdService != null)
			cmdService.getCommand(REFRESH_ID).removeExecutionListener(this);
	}

	public void notHandled(String commandId, NotHandledException exception) {}

	public void postExecuteFailure(String commandId, ExecutionException exception) {}

	public void postExecuteSuccess(String commandId, Object returnValue) {}

	public void preExecute(String commandId, ExecutionEvent event) {
		final List<IAdaptable> selectionObject = (List<IAdaptable>)((EvaluationContext) event.getApplicationContext()).getDefaultVariable();
		final Set<IResource> projects = new HashSet<IResource>();
		for (IAdaptable adaptable : selectionObject) {
			final IResource res = (IResource)adaptable.getAdapter(IResource.class);
			if(res != null) {
				final IProject proj = res.getProject();
				BazaarTeamProvider provider = BzrWorkspaceRoot.getProviderFor(proj);
				if(provider != null) {
					IBzrBranch branch = provider.getBranch();
					if(!branch.getPath().equals(proj.getLocation())) {
						projects.add(proj);
						ResourceUtil.cleanCache(new IResource[]{proj});
					}
				}
			}
		}
		refreshResources(projects);
	}

	public void resourceChanged(IResourceChangeEvent event) {
		// don't do anything, just subclass from AbstractResourceChangeListener to avoid code duplication of job creation code
	}
}