/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.views;

import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.SashForm;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.MouseListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.vcs.bazaar.eclipse.core.listeners.BzrChangeStateEvent;
import org.vcs.bazaar.eclipse.core.model.IBzrMissingRevisions;
import org.vcs.bazaar.eclipse.ui.history.HistoryTree;

/**
 * A simple view to show the missing/extra revisions between two branches
 * 
 * @author Guillermo Gonzalez
 *
 */
public class MissingView extends BazaarView {

	private IBzrMissingRevisions missingRevisions;
	private Composite missingControl;
	private Composite extraControl;
	private HistoryTree missingTree;
	private HistoryTree extraTree;
	private static final int DEFAULT_WEIGHT = 1;
	private static final int MAX_WEIGHT = 10;

	public void createPartControl(Composite parent) {
		SashForm control = new SashForm(parent, SWT.VERTICAL);
		control.setLayoutData(new GridData(GridData.FILL_BOTH));
		missingControl = new Composite(control, SWT.NONE);
		missingControl.setLayout(new GridLayout(1, false));
		missingControl.setLayoutData(new GridData(GridData.FILL_BOTH));
		Label label = new Label(missingControl, SWT.BORDER);
		label.setText("Missing revisions");
		setTitleListener(label, control);
		missingTree = new HistoryTree(missingControl, SWT.FILL);
		extraControl = new Composite(control, SWT.NONE);
		extraControl.setLayout(new GridLayout(1, false));
		extraControl.setLayoutData(new GridData(SWT.DEFAULT, 20));
		label = new Label(extraControl, SWT.BORDER);
		label.setText("Extra revisions");
		setTitleListener(label, control);
		extraTree = new HistoryTree(extraControl, SWT.NONE);
		control.setWeights(new int[]{DEFAULT_WEIGHT, DEFAULT_WEIGHT});
	}
	
	private void setTitleListener(Label label, final SashForm parent) {
		label.addMouseListener(new MouseListener() {
			
			public void mouseDoubleClick(MouseEvent e) {
				if (e.getSource() instanceof Label) {
					Label label = (Label)e.getSource();
					int[] weights = parent.getWeights();
					if ("Missing revisions".equals(label.getText())) {
						parent.setWeights(new int[] { weights[0] > weights[1] ? DEFAULT_WEIGHT : MAX_WEIGHT, DEFAULT_WEIGHT });
					} else {
						parent.setWeights(new int[] { 1, weights[1] > weights[0] ? DEFAULT_WEIGHT : MAX_WEIGHT });
					}
				}
			}

			public void mouseDown(MouseEvent e) {}
			public void mouseUp(MouseEvent e) {}
			
		});
	}

	public void setFocus() {
	// TODO Auto-generated method stub
	}

	public void resourceStateChanged(final BzrChangeStateEvent event) {
		// TODO Auto-generated method stub
	}

	public void setInput(Object object) {
		if(object instanceof IBzrMissingRevisions) {
			missingRevisions = (IBzrMissingRevisions)object;
		}
		refresh();
	}

	private void refresh() {
		populateMissingRevisions();
		populateExtraRevisions();
	}

	private void populateExtraRevisions() {
		extraTree.populate(missingRevisions.getExtraRevisions());
	}

	private void populateMissingRevisions() {
		missingTree.populate(missingRevisions.getMissingRevisions());
	}

}
