/**
 * 
 */
package org.vcs.bazaar.eclipse.ui.widgets;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IResource;
import org.eclipse.jface.layout.GridDataFactory;
import org.eclipse.jface.layout.TableColumnLayout;
import org.eclipse.jface.viewers.ArrayContentProvider;
import org.eclipse.jface.viewers.CheckboxTableViewer;
import org.eclipse.jface.viewers.ColumnWeightData;
import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableColumn;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.ide.IDE;
import org.vcs.bazaar.eclipse.core.model.IBzrResourceStatus;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.dialogs.CommitResourceLabelProvider;
import org.vcs.bazaar.eclipse.ui.dialogs.UntrackedFilesFilter;
import org.vcs.bazaar.eclipse.ui.operations.DiffOperation;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 *
 */
public class BzrResourceSelectionComposite {

	private Composite control;
	private TableViewer tableViewer;
	private List<IBzrResourceStatus> resources;
	private List<IBzrResourceStatus> selection;
	private Button selectAllButton;
	private Button deselectAllButton;
	private UntrackedFilesFilter untrackedFilesFilter;
	private boolean filterUntracked = false;
	private boolean checkBox = true;
	
	public BzrResourceSelectionComposite(boolean checkBox) {
		super();
		resources = selection = Collections.emptyList();
		untrackedFilesFilter = new UntrackedFilesFilter();
		this.checkBox = checkBox;
	}
	
	public BzrResourceSelectionComposite() {
		this(true);
	}
	
	private void createFilesList(Composite parent) {
		int tableStyle;
		if(checkBox) {
			tableStyle = SWT.H_SCROLL | SWT.V_SCROLL | SWT.FULL_SELECTION | SWT.MULTI | SWT.CHECK | SWT.BORDER;
		} else {
			tableStyle = SWT.H_SCROLL | SWT.V_SCROLL | SWT.FULL_SELECTION | SWT.MULTI | SWT.BORDER;
		}
		Composite container = new Composite(parent, SWT.NONE);
        
		final Table table = new Table(container, tableStyle);
		table.setHeaderVisible(true);
		table.setLinesVisible(true);
		
		TableColumnLayout layout = new TableColumnLayout(); 
		container.setLayout(layout);
		// File name
		final TableColumn file = new TableColumn(table, SWT.LEFT);
		file.setResizable(true);
		file.setText("File");
		layout.setColumnData(file, new ColumnWeightData(60, true));

		// File status
		final TableColumn status = new TableColumn(table, SWT.CENTER);
		status.setResizable(true);
		status.setText("Status");
		status.setMoveable(false);
		layout.setColumnData(status, new ColumnWeightData(30, false));
		
		// creating a comparator right now to get column listeners
//		ResourcesTableComparator comparator = new ResourcesTableComparator(this.tableViewer);
//		col.addSelectionListener(comparator);
		
		if(checkBox) {
			tableViewer = new CheckboxTableViewer(table);
		} else {
			tableViewer = new TableViewer(table);
		}

		// adding comparator and selection default sorting column and direction
//		this.tableViewer.setComparator(comparator);
//		comparator.setColumnNumber(ResourceSelectionComposite.COLUMN_STATUS);
//		this.tableViewer.getTable().setSortColumn(this.tableViewer.getTable().getColumn(ResourceSelectionComposite.COLUMN_STATUS));
//		this.tableViewer.getTable().setSortDirection(SWT.UP);
		
		tableViewer.setContentProvider(new ArrayContentProvider());
		tableViewer.setLabelProvider(new CommitResourceLabelProvider());
		
		this.tableViewer.addDoubleClickListener(new IDoubleClickListener() {
			public void doubleClick(DoubleClickEvent event) {
				IStructuredSelection sel = (IStructuredSelection) tableViewer.getSelection();
				if (sel.getFirstElement() instanceof IBzrResourceStatus) {
					IBzrResourceStatus status = (IBzrResourceStatus) sel.getFirstElement();
					if ((status.isAdded() || status.isUnknown()) && status.getResource().getIResource().getType() == IResource.FILE && EclipseBazaarUI.getActivePage() != null) {
						try {
							IDE.openEditor(EclipseBazaarUI.getActivePage(), (IFile) status.getResource().getIResource());
						} catch (PartInitException e) {
							EclipseBazaarUI.log(e);
						}
					} else if(!status.isDeleted()) {
						DiffOperation.openDialog(status.getResource().getIResource());
					}
				}
			}
		});
		
		GridDataFactory gf = GridDataFactory.fillDefaults().align(GridData.FILL, GridData.FILL).grab(true, true);
        gf.applyTo(container);
        
	}
	
	/**
	 * Adds a label just on top of the {@link CheckboxTableViewer}
	 * The default implementation don't add any label
	 * @param container
	 */
	protected void createUpperControls(Composite container) {

	}


	public Composite createControls(Composite container) {
		control = new Composite(container, SWT.NONE);
		control.setLayout(new GridLayout());

		createUpperControls(control);
		createMiddleControls(control);
		createBottomControls(control);
		return control;
	}

	protected void createBottomControls(Composite control) {
		Composite optionComposite = createOptionComposite(control);
		createButtons(optionComposite);
		createOption(optionComposite);
	}

	protected void createMiddleControls(Composite control) {
		createFilesList(control);
	}

	/**
	 * create the options section.
	 * The default implemention don't add any widget, 
	 * it's subclass responsability to implement this as needed.
	 * 
	 * @param optionComposite
	 */
	protected void createOption(Composite optionComposite) {
		// TODO Auto-generated method stub	
	}

	protected Composite createOptionComposite(Composite container) {
		Composite optionsContainer = new Composite(container, SWT.NONE);
		optionsContainer.setLayout(new GridLayout(1, false));
		GridData data = new GridData();
        data.horizontalAlignment = GridData.FILL;
        data.verticalAlignment = GridData.END;
        data.grabExcessHorizontalSpace = true;
        data.grabExcessVerticalSpace = false;
        optionsContainer.setLayoutData(data);
		return optionsContainer;
	}


	/**
	 * @param tComposite
	 * @return 
	 */
	protected Composite createButtons(Composite container) {
		Composite buttonContainer = new Composite(container, SWT.NONE);
		buttonContainer.setLayout(new GridLayout(2, false));
		selectAllButton = new Button(buttonContainer, SWT.NONE);
		selectAllButton.setText("Select All");
		deselectAllButton = new Button(buttonContainer, SWT.NONE);
		deselectAllButton.setText("Deselect All");


		SelectionListener listener = new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				if(checkBox && tableViewer.getTable().getEnabled()) {
					((CheckboxTableViewer)tableViewer).setAllChecked(true);
				}
			}
		};
		selectAllButton.addSelectionListener(listener);
		
		listener = new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				if(checkBox && tableViewer.getTable().getEnabled()) {
					((CheckboxTableViewer)tableViewer).setAllChecked(false);
				}
			}
		};
		deselectAllButton.addSelectionListener(listener);
		
		GridData data = new GridData(GridData.FILL, GridData.BEGINNING, false, false);
		buttonContainer.setLayoutData(data);
		data = new GridData();
        data.horizontalAlignment = GridData.FILL;
        data.verticalAlignment = GridData.BEGINNING;
        data.grabExcessHorizontalSpace = true;
        data.grabExcessVerticalSpace = false;
        this.deselectAllButton.setLayoutData(data);
        this.selectAllButton.setLayoutData(data);
        data = new GridData();
        data.horizontalAlignment = GridData.FILL;
        data.verticalAlignment = GridData.END;
        data.grabExcessHorizontalSpace = true;
        data.grabExcessVerticalSpace = false;
        buttonContainer.setLayoutData(data);
        return buttonContainer;
	}
	
	public void addUntrackedFilesFilter() {
		if(!filterUntracked) {
			tableViewer.addFilter(untrackedFilesFilter);
			filterUntracked = true;
		}
	}
	
	public void removeUntrackedFilesFilter() {
		if(filterUntracked) {
			tableViewer.removeFilter(untrackedFilesFilter);
			filterUntracked = false;
		}
	}
	
	public void setResources(List<IBzrResourceStatus> resources) {
		this.resources = resources;
	}
	
	public List<IBzrResourceStatus> getResources() {
		return resources;
	}
	
	public List<IBzrResourceStatus> getSelection() {
		if(checkBox) {
			Object[] checkedElements = ((CheckboxTableViewer)tableViewer).getCheckedElements();
			this.selection.clear();
			for (Object checked : checkedElements) {
				this.selection.add((IBzrResourceStatus)checked);	
			}
		}
		return selection;
	}
	
	public void setSelection(List<IBzrResourceStatus> selection) {
		this.selection = selection;
	}
	
	public boolean isFilterUntracked() {
		return filterUntracked;
	}
	
	/**
	 * reload the resources, uncheck all, and then select only the resources in selection List
	 */
	public void refreshTableViewer() {
		tableViewer.setInput(resources);
		tableViewer.refresh(true);
		if(checkBox) {
			((CheckboxTableViewer)tableViewer).setAllChecked(false);
			for (IBzrResourceStatus bzrResourceStatus : this.selection) {
				((CheckboxTableViewer)tableViewer).setChecked(bzrResourceStatus, true);
			}
		}
	}

	public TableViewer getTableViewer() {
		return tableViewer;
	}
	
}
