/**
 * 
 */
package org.vcs.bazaar.eclipse.ui.widgets;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.DisposeEvent;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Text;
import org.vcs.bazaar.eclipse.ui.UITexts;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 *
 */
public class RevisionNumber extends Composite {

	private static final int REVISION_WIDTH_HINT = 40;
	
	private Text revisionText;
	private Button tipButton;
	private Button revisionButton;
	private Composite control;
	private Button logButton;
	
	public RevisionNumber(Composite parent) {
		super(parent, SWT.NONE);
		createControl();
		addDisposeListener(new DisposeListener() {
			public void widgetDisposed(DisposeEvent e) {
				RevisionNumber.this.dispose();
			}
		});
		this.setLayout(parent.getLayout());
	}
	
	private void createControl() {
		control = new Composite(this, SWT.NONE);
		GridLayout revisionLayout = new GridLayout();
		revisionLayout.numColumns = 3;
		control.setLayout(revisionLayout);
		
		tipButton = new Button(control, SWT.RADIO);
		tipButton.setText(UITexts.SelectRevision_tip); //$NON-NLS-1$
		GridData data = new GridData();
		data.horizontalSpan = 3;
		tipButton.setLayoutData(data);
		
		revisionButton = new Button(control, SWT.RADIO);
		revisionButton.setText(UITexts.SelectRevision_revision); //$NON-NLS-1$
		
		tipButton.setSelection(true);
		
		revisionText = new Text(control, SWT.BORDER);
		data = new GridData();
		data.widthHint = REVISION_WIDTH_HINT;
		revisionText.setLayoutData(data);
		revisionText.setEnabled(false);
		
		logButton = new Button(control, SWT.PUSH);
		logButton.setText(UITexts.SelectRevision_showLog); //$NON-NLS-1$
		
		SelectionListener revisionListener = new SelectionAdapter() {
			
			@Override
            public void widgetSelected(SelectionEvent e) {
                revisionText.setEnabled(revisionButton.getSelection());
                if (revisionButton.getSelection()) {
                    revisionText.selectAll();
                    revisionText.setFocus();
                }               
            }
		};
		
		tipButton.addSelectionListener(revisionListener);
		revisionButton.addSelectionListener(revisionListener);	
	}
	
	public void addShowLogButtonSelectionListener(SelectionListener listener) {
		logButton.addSelectionListener(listener);
	}
	
	public String getRevision() {
		return revisionText.getText();
	}
	
	public boolean isRevisionSelected() {
		return revisionButton.getSelection();
	}
	
	public boolean isTipSelected() {
		return tipButton.getSelection();
	}
	
	public void setRevision(String revisionText) {
		this.revisionText.setText(revisionText);
		selectRevisionButton(true);
		selectTipButton(false);
		this.revisionText.setEnabled(true);
	}
	
	public void selectTipButton(boolean selected) {
		this.tipButton.setSelection(selected);
	}
	
	public void selectRevisionButton(boolean selected) {
		this.revisionButton.setSelection(selected);
	}
	
	@Override
	public void setEnabled(boolean enabled) {
		revisionButton.setEnabled(enabled);
		revisionText.setEnabled(enabled);
		tipButton.setEnabled(enabled);
		logButton.setEnabled(enabled);
		control.setEnabled(enabled);
		super.setEnabled(enabled);
	}
	
	@Override
	public void dispose() {
		revisionButton.dispose();
		revisionText.dispose();
		tipButton.dispose();
		control.dispose();
		super.dispose();
	}
	
	@Override
	public void setVisible(boolean visible) {
		revisionButton.setVisible(visible);
		revisionText.setVisible(visible);
		tipButton.setVisible(visible);
		control.setVisible(visible);
		super.setVisible(visible);
	}

	public void showLogButton(boolean visible) {
		this.logButton.setVisible(visible);
	}
	
}
