/**
 * 
 */
package org.vcs.bazaar.eclipse.ui.wizards.configuration;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.team.ui.IConfigurationWizard;
import org.eclipse.ui.IWorkbench;
import org.vcs.bazaar.eclipse.EclipseBazaarCore;
import org.vcs.bazaar.eclipse.core.repository.BazaarTeamProvider;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.actions.InitAction;
import org.vcs.bazaar.eclipse.ui.decorator.BazaarLightweightDecorator;
import org.vcs.bazaar.eclipse.ui.team.BazaarUtilities;

/**
 * Bazaar configuration Wizard
 * 
 * This wizard will dig up the project root and then 
 * it lets you modify the directory, when you are done it will 
 * create a bazaar repository (only if it's needed)
 * 
 * It will follow the directory chain to the bottom to see if
 * there is a .bzr directory somewhere, is so it will suggest that you use it
 * instead of creating a new repository.
 *
 * @author zingo
 * @modifiedBy Guillermo Gonzalez <guillo.gonzo at gmail dot com>
 */
public class BazaarConfigurationWizard extends Wizard implements IConfigurationWizard {
	private IProject project;
	private BranchRootPage branchRootPage;

	public BazaarConfigurationWizard() {
		setWindowTitle(UITexts.ConfigurationWizard_wizardTitle);
	}


	public void addPages() {
		if (project == null)
			return;
		branchRootPage = new BranchRootPage(project);
		addPage(branchRootPage);
	}

	public boolean performFinish() {
		if (!branchRootPage.isExistingBranch()) {
			new InitAction(branchRootPage.getPath(), project, getShell()).run(null);
		}
		try {
			BazaarTeamProvider.registerProject(project, branchRootPage.getPath());
		} catch (CoreException e) {
			EclipseBazaarUI.getDefault().getLog().log(e.getStatus());
			return false;		
		}
		BazaarLightweightDecorator.refresh();
		return true;
	}

	public void init(IWorkbench workbench, IProject project) {
		this.project = project;
		if (!EclipseBazaarCore.getDefault().isClientAvailable()) {
			BazaarUtilities.configureExecutable();
		}
	}

}
