/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.wizards.configuration;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.Path;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.vcs.bazaar.eclipse.core.utils.ResourceUtil;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.wizards.BzrWizardPage;

/**
 * 
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 * TODO: check that the specified path isn't a subdir of the project
 */
public class BranchRootPage extends BzrWizardPage{
	private IPath bzrPath;
	private IPath bzrPathOriginal;
	private IPath foundBzrPath;

	public BranchRootPage(IProject project) {
		super(BranchRootPage.class.getName());
		setTitle(UITexts.ConfigurationWizard_wizard_page_title);
		IPath repoPath = ResourceUtil.getRepositoryPath(project);
		if (repoPath == null) {
			foundBzrPath = null;
			bzrPath = bzrPathOriginal = project.getLocation();
			setDescription(UITexts.ConfigurationWizard_version_control_new_project);
		} else {
			bzrPath = bzrPathOriginal = foundBzrPath = repoPath;
			setDescription(UITexts.ConfigurationWizard_version_control_existing_project);
		}		
		setPageComplete(true); /* tell that it has the needed info */
	}

	public void createControl(final Composite parent) {		
		final Composite mainControl = new Composite(parent, SWT.NONE);
		mainControl.setLayout(new GridLayout(3, false));

		new Label(mainControl, SWT.CENTER).setText(UITexts.ConfigurationWizard_label_select_dir);

		final Text directoryText = new Text(mainControl, SWT.BORDER);
		directoryText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		directoryText.setText(bzrPath.toString());
		directoryText.addSelectionListener(new SelectionAdapter(){
			@Override
			public void widgetSelected(SelectionEvent e) {
				setPath(new Path(directoryText.getText()));
				directoryText.setText(getPath().toString());
			}
		});

		final Button changeDirButton = new Button(mainControl, SWT.CENTER | SWT.PUSH);
		changeDirButton.setText(UITexts.ConfigurationWizard_button_change_dir);
		changeDirButton.addSelectionListener(new SelectionAdapter(){
			@Override
			public void widgetSelected(SelectionEvent e) {				
				final DirectoryDialog directoryDialog = new DirectoryDialog(new Shell());
				directoryDialog.setText(UITexts.ConfigurationWizard_button_select_bzr_root);
				directoryDialog.setMessage(UITexts.ConfigurationWizard_button_select_bzr_root_msg);
				setPath(new Path(directoryDialog.open()));
				directoryText.setText(bzrPath.toString());
			}
		});
		
		final Button restoreDefaultDirButton = new Button(mainControl, SWT.CENTER | SWT.PUSH);
		restoreDefaultDirButton.setText(UITexts.ConfigurationWizard_button_use_project_root);
		restoreDefaultDirButton.addSelectionListener(new SelectionAdapter(){
			@Override
			public void widgetSelected(SelectionEvent e) {
				setDefaultPath();
				directoryText.setText(bzrPath.toString());
			}
		});

		final Button restoreExistingDirButton = new Button(mainControl, SWT.CENTER | SWT.PUSH);
		restoreExistingDirButton.setText(UITexts.ConfigurationWizard_button_use_existing_bzr_dir);
		restoreExistingDirButton.addSelectionListener(new SelectionAdapter(){
			@Override
			public void widgetSelected(SelectionEvent e) {
				if(foundBzrPath != null) {
					bzrPath = foundBzrPath;
					directoryText.setText(bzrPath.toString());
				}
			}
		});
		if(foundBzrPath == null) {
			restoreExistingDirButton.setEnabled(false);
		}
		setControl(mainControl);
		setPageComplete(true);
	}

	@Override
	public BazaarConfigurationWizard getWizard() {
		return (BazaarConfigurationWizard)super.getWizard();
	}
	
	public boolean isExistingBranch() {
		return (foundBzrPath != null) && !foundBzrPath.equals(bzrPath);
	}

	public IPath getPath() {
		return bzrPath;
	}
	
	public void setPath(Path path) {
		bzrPath = path;
	}
	
	public void setDefaultPath() {
		bzrPath = bzrPathOriginal;
	}
}