/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.wizards.project;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.swt.widgets.Shell;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.operations.BranchAsProjectOperation;

/**
 * This class implements the branch from project wizard 
 * 
 * @author Guillermo Gonzalez <guillo.gonzo at gmail dot com>
 */
public class BranchFromProjectWizard extends BranchWizard {
	
	public BranchFromProjectWizard(Shell shell, IBzrBranch branch) {
		super();
		setRemoteLocation(branch);
		init(null, null);
	}
	
	public static BranchFromProjectWizard open(Shell shell, IBzrBranch branch) {
		BranchFromProjectWizard wizard = new BranchFromProjectWizard(shell, branch);
		WizardDialog dialog = new WizardDialog(shell, wizard);
		dialog.open();
		return wizard;
	}


	protected boolean performOperation(IProject project) {
		BranchAsProjectOperation branchOp = null;
		if(project == null) {
			IProjectDescription description = ResourcesPlugin.getWorkspace().newProjectDescription(getNewProjectPage().getProjectName());
			description.setLocation(getNewProjectPage().getLocationPath());
			branchOp = new BranchAsProjectOperation(this.getContainer(), getRemoteLocation(), description, getProjectPage().getRevision());
		} else {
			branchOp = new BranchAsProjectOperation(this.getContainer(), getRemoteLocation(), project, getProjectPage().getRevision());
		}
		try {
			branchOp.run();
		} catch (Exception e) {
			MessageDialog.openError(this.getShell(), "Error while executing branch operation", e.getMessage());
			EclipseBazaarUI.log(e.getMessage(), e);
			return false;
		}
		return true;
	}

	@Override
	public void addPages() {
		//super.addPages();
		addPage(getProjectPage());
		addPage(getNewProjectPage());
	}
	
	@Override
	public IWizardPage getNextPage(IWizardPage page) {
		if(page != null) {
			if(page.getName().equals(getProjectPage().getName())) {
				if(getProjectPage().useNewProjectWizard()) {
					setUseNewProjectWizard(true);
					return null;
				} else {
					setUseNewProjectWizard(false);
					return getNewProjectPage();
				}
			} else if(page.getName().equals(getNewProjectPage().getName())) {
				return null;		
			}
		}
		return super.getNextPage(page);
	}
	
	@Override
	public IWizardPage getPreviousPage(IWizardPage page) {
		if(page != null) {
			if(page.getName().equals(getNewProjectPage().getName())) {
				return getProjectPage();
			}
		}
		return super.getPreviousPage(page);
	}
	
}
