/*******************************************************************************
 * Copyright (c) 2006 Software Balm Consulting Inc.
 * 
 * This software is licensed under the zlib/libpng license.
 * 
 * This software is provided 'as-is', without any express or implied warranty. 
 * In no event will the authors be held liable for any damages arising from the
 * use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose, 
 * including commercial applications, and to alter it and redistribute it freely,
 * subject to the following restrictions:
 *
 *  1. The origin of this software must not be misrepresented; you must not 
 *            claim that you wrote the original software. If you use this 
 *            software in a product, an acknowledgment in the product 
 *            documentation would be appreciated but is not required.
 *
 *   2. Altered source versions must be plainly marked as such, and must not be
 *            misrepresented as being the original software.
 *
 *   3. This notice may not be removed or altered from any source distribution.
 *******************************************************************************/
package org.vcs.bazaar.eclipse.ui.wizards.project;

import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.Label;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.core.repository.BranchFactory;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.wizards.BzrWizardPage;

/*
 * @author Peter Hunnisett <peter_hge at softwarebalm dot com>
 * 
 * This file implements a wizard page which will allow the user to create a
 * repository location.
 * 
 */
public class BranchWizardBranchLocationPage extends BzrWizardPage implements IWizardPage {
	private String location;
	/**
	 * 
	 * @param pageName
	 * @param title
	 */
	public BranchWizardBranchLocationPage(String pageName, String title) {
		super(pageName);
		setTitle(title);
		setDescription(UITexts.Branch_Wizard_page_description);
	}

	public boolean canFlipToNextPage() {
		return isPageComplete() && (getWizard().getNextPage(this) != null);
	}

	public void createControl(Composite parent) {
		final Composite outerContainer = new Composite(parent, SWT.NONE);
		outerContainer.setLayout(new GridLayout(1,false));
		outerContainer.setLayoutData(new GridData(GridData.GRAB_HORIZONTAL | GridData.HORIZONTAL_ALIGN_FILL));

		// Three columns for the location + browse + revno
		final Composite locationContainer = new Composite(outerContainer, SWT.NONE);
		locationContainer.setLayout(new GridLayout(3,false));
		locationContainer.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));

		// Box to enter the repo location
		final Composite repoLocationContainer = new Composite(locationContainer, SWT.NONE);
		repoLocationContainer.setLayout(new GridLayout(2,false));
		repoLocationContainer.setLayoutData(new GridData(GridData.GRAB_HORIZONTAL | GridData.HORIZONTAL_ALIGN_FILL));
		
		final Label locationLabel = new Label(repoLocationContainer, SWT.NONE);
		locationLabel.setText(UITexts.Branch_Wizard_page_branch_location_label);
		final GridData locationData = new GridData(SWT.VERTICAL);
		locationData.widthHint = 500;
		final Combo locationCombo = new Combo(repoLocationContainer, SWT.DROP_DOWN);
		locationCombo.setLayoutData(locationData);
		
		final Button browseButton = new Button(locationContainer, SWT.PUSH);
		browseButton.setText(UITexts.Branch_Wizard_page_branch_location_browse_button);
		browseButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				final DirectoryDialog dialog = new DirectoryDialog(getShell());
				dialog.setMessage(UITexts.Branch_Wizard_page_branch_location_dialog_message);
				final String dir = dialog.open();
				if (dir != null){
					locationCombo.setText(dir);
				}
			}
		});

		locationCombo.addSelectionListener(new SelectionAdapter(){
			@Override
			public void widgetSelected(SelectionEvent e) {				
				location = locationCombo.getText();
				setPageComplete(isPageComplete());
			}
		});
		locationCombo.addModifyListener(new ModifyListener(){

			public void modifyText(ModifyEvent e) {
				location = locationCombo.getText();
				setPageComplete(isPageComplete());
			}
		});
		
		setControl(outerContainer);
		locationCombo.setFocus();
		setPageComplete(false);
	}
	
	@Override
	public boolean isPageComplete() {
		if(location == null || location.length() == 0){		
			setMessage(UITexts.Branch_Wizard_page_branch_location_error_location_notspecified);
			return false;
		}
		if(!BranchFactory.validateBranch(location)){
			setMessage(UITexts.Branch_Wizard_page_branch_location_error_location_invalid);
			return false;
		}		
		setMessage(null);
		return true;
	}
	
	public IBzrBranch getLocation() {
		return BranchFactory.getInstance().findOrCreateFor(location);
	}
	
}
