/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.wizards.project;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IMessageProvider;
import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.layout.RowData;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.dialogs.ShowLogDialog;
import org.vcs.bazaar.eclipse.ui.widgets.RevisionNumber;
import org.vcs.bazaar.eclipse.ui.wizards.BzrWizardPage;

/**
 * @author "Guillermo Gonzalez <guillo.gonzo at gmail dot com>" 
 *
 */
public class BranchWizardProjectPage extends BzrWizardPage implements IWizardPage {
	
	private Label textLabel;
	private Button wizardButton;
	private Button projectsButton;
	private Group revisionGroup;
	private RevisionNumber revision;
	private IBzrBranch remoteLocation;
	private final boolean isCheckout;
	private Button lightWegithButton;
	
	protected BranchWizardProjectPage(String pageName, boolean isCheckout) {
		super(pageName);
		this.isCheckout = isCheckout;
	}

	public void createControl(Composite parent) {
		Composite outerContainer = new Composite(parent,SWT.NONE);
		GridLayout layout = new GridLayout();
		layout.numColumns = 1;
		outerContainer.setLayout(layout);
		outerContainer.setLayoutData(
		new GridData(GridData.GRAB_HORIZONTAL | GridData.HORIZONTAL_ALIGN_FILL));
		
		textLabel = new Label(outerContainer, SWT.NONE);
		GridData data = new GridData();
		data.widthHint = 300;
		textLabel.setLayoutData(data);
		
		wizardButton = new Button(outerContainer, SWT.RADIO);
		wizardButton.setText(UITexts.BranchWizardProjectPage_wizard); //$NON-NLS-1$
		wizardButton.setEnabled(true);
		
		projectsButton = new Button(outerContainer, SWT.RADIO);
		projectsButton.setText(UITexts.BranchWizardProjectPage_projects); //$NON-NLS-1$
		
		SelectionListener projectWizardTypeListener = new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				setPageComplete(isPageComplete());
			}
		};

		projectsButton.addSelectionListener(projectWizardTypeListener);
		wizardButton.addSelectionListener(projectWizardTypeListener);
		
		if(isCheckout) {
			lightWegithButton = new Button(outerContainer, SWT.CHECK);
			lightWegithButton.setText(UITexts.CheckoutWizardProjectPage_lightweight);
			lightWegithButton.setSelection(false);
			lightWegithButton.addSelectionListener(new SelectionAdapter() {
				@Override
				public void widgetSelected(SelectionEvent e) {
					BranchWizardProjectPage.this.revision.setEnabled(!lightWegithButton.getSelection());
				}
			});
		}
		
		createRevisionGroup(outerContainer);
		
		setControl(outerContainer);
		projectsButton.setSelection(true);
		projectsButton.setFocus();
		/* FIXME: TODO: Enable the project wizard
		 * temprary disabled. Until I can create the project but not the folder 
		 * and can branch previous to the project folder creation
		 */
		wizardButton.setEnabled(false);
		setPageComplete(false);
	}
	
	private void createRevisionGroup(Composite parent) {
		revisionGroup = new Group(parent, SWT.NULL);
		revisionGroup.setText(UITexts.BranchWizardProjectPage_revision); //$NON-NLS-1$
		GridData data = new GridData(GridData.FILL_BOTH);
		revisionGroup.setLayoutData(data);
		revisionGroup.setLayout(new RowLayout(SWT.VERTICAL));
		
		revision = new RevisionNumber(revisionGroup);
		revision.setLayoutData(new RowData());
		revision.addShowLogButtonSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				showLog();
			}
		});
	}
	
	protected void showLog() {
		if(this.remoteLocation != null && !isLigthWeight()) {
			ShowLogDialog dialog = new ShowLogDialog(getShell(), this.remoteLocation);
			if(dialog.open() == Dialog.OK && dialog.getSelectedRevision() != null) {
				revision.setRevision(dialog.getSelectedRevision().getValue());
			}
		}
	}
	
	protected void setLocation(IBzrBranch remoteLocation) {
		this.remoteLocation = remoteLocation;		
	}
	
	@Override
	public boolean isPageComplete() {
		if(revision.isRevisionSelected()) {
			if(revision.getRevision().trim().length() != 0){
				setMessage(null);
				return true;
			}
			setMessage("specify a revision number",IMessageProvider.ERROR);
			return false;
		} else if(revision.isTipSelected()) {
			setMessage(null);
			return true;
		}
		return false;
	}

	public String getRevision() {
		return revision.getRevision();
	}
	
	public boolean useSpecificRevision() {
		return revision.isRevisionSelected();
	}

	public boolean useNewProjectWizard() {
		return wizardButton.getSelection();
	}
	
	public boolean isLigthWeight() {
		if(isCheckout) {
			return lightWegithButton.getSelection();
		} 
		return false;
	}
	@Override
	public void dispose() {
		textLabel.dispose();
		wizardButton.dispose();
		projectsButton.dispose();
		revision.dispose();
		revisionGroup.dispose();
		super.dispose();
	}

}
