/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.wizards.project;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.swt.widgets.Shell;
import org.vcs.bazaar.eclipse.core.model.IBzrBranch;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.operations.CheckoutAsProjectOperation;

/**
 * This class implements the checkout(and lightweight) from project wizard 
 * 
 * @author Guillermo Gonzalez <guillo.gonzo at gmail dot com>
 */
public class CheckoutFromProjectWizard extends BranchFromProjectWizard {
	
	private boolean lightweight;
	
	public CheckoutFromProjectWizard(Shell shell, IBzrBranch branch, boolean lightweight) {
		super(shell, branch);
		this.lightweight = lightweight;
	}
	
	public static CheckoutFromProjectWizard open(Shell shell, IBzrBranch branch, boolean lightweight) {
		CheckoutFromProjectWizard wizard = new CheckoutFromProjectWizard(shell, branch, lightweight);
		WizardDialog dialog = new WizardDialog(shell, wizard);
		dialog.open();
		return wizard;
	}


	public boolean performOperation(IProject project) {
		CheckoutAsProjectOperation checkoutOp = null;
		if(project == null) {
			IProjectDescription description = ResourcesPlugin.getWorkspace().newProjectDescription(getNewProjectPage().getProjectName());
			description.setLocation(getNewProjectPage().getLocationPath());
			checkoutOp = new CheckoutAsProjectOperation(this.getContainer(), getRemoteLocation(), description, getProjectPage().getRevision(), lightweight);
		} else {
			checkoutOp = new CheckoutAsProjectOperation(this.getContainer(), getRemoteLocation(), project, getProjectPage().getRevision(), lightweight);
		}
		try {
			checkoutOp.run();
		} catch (Exception e) {
			MessageDialog.openError(this.getShell(), "Error while executing branch operation", e.getMessage());
			EclipseBazaarUI.log(e.getMessage(), e);
			return false;
		}
		return true;
	}
}
