/**
 * LICENSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.wizards.project;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.jface.dialogs.MessageDialog;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.operations.CheckoutAsProjectOperation;

/**
 * This class implements the new wizard extension.
 * 
 * @author Guillermo Gonzalez <guillo.gonzo at gmail dot com>
 */
public class CheckoutWizard extends BranchWizard {


	protected boolean performOperation(IProject project) {
		CheckoutAsProjectOperation checkoutOp = null;
		if(project == null) {
			IProjectDescription description = ResourcesPlugin.getWorkspace().newProjectDescription(getNewProjectPage().getProjectName());
			description.setLocation(getNewProjectPage().getLocationPath());
			checkoutOp = new CheckoutAsProjectOperation(this.getContainer(), getRemoteLocation(), description, getProjectPage().getRevision(), getProjectPage().isLigthWeight());
		} else {
			checkoutOp = new CheckoutAsProjectOperation(this.getContainer(), getRemoteLocation(), project, getProjectPage().getRevision(), getProjectPage().isLigthWeight());
		}
		try {
			checkoutOp.run();
		} catch (Exception e) {
			MessageDialog.openError(this.getShell(), "Error while executing checkout operation", e.getMessage());
			EclipseBazaarUI.log(e.getMessage(), e);
			return false;
		}
		return true;
	}
	
	@Override
	protected boolean isCheckout() {
		return true;
	}
}
